@@ -227,6 +227,27 @@ int quisk_dDecimate(double * dSamples, int count, struct quisk_dFilter * filter,
 	return nOut;
 }
 
+double quisk_dD_out(double samp, struct quisk_dFilter * filter)
+{	// Filter double samples.
+	int k;
+	double * ptSample;
+	double * ptCoef;
+	double dsample;
+
+	*filter->ptdSamp = samp;
+	dsample = 0;
+	ptSample = filter->ptdSamp;
+	ptCoef = filter->dCoefs;
+	for (k = 0; k < filter->nTaps; k++, ptCoef++) {
+		dsample += *ptSample  *  *ptCoef;
+		if (--ptSample < filter->dSamples)
+			ptSample = filter->dSamples + filter->nTaps - 1;
+	}
+	if (++filter->ptdSamp >= filter->dSamples + filter->nTaps)
+		filter->ptdSamp = filter->dSamples;
+    return dsample;
+}
+
 int quisk_dFilter(double * dSamples, int count, struct quisk_dFilter * filter)
 {	// Filter double samples.
 	int i, k, nOut;
@@ -252,6 +273,11 @@ int quisk_dFilter(double * dSamples, int count, struct quisk_dFilter * filter)
 	return nOut;
 }
 
+int quisk_cFilter(complex * cSamples, int count, struct quisk_cFilter * filter)
+{	// Filter complex samples using the double coefficients of filter (not the complex).
+	return quisk_cDecimate(cSamples, count, filter, 1);
+}
+
 int quisk_cDecim2HB45(complex * cSamples, int count, struct quisk_cHB45Filter * filter)
 {	// This uses the double coefficients of filter (not the complex).
 // Half band filter, sample rate 96 Hz, pass 16, center 24, stop 32, good BW 2/3, 45 taps.
