@@ -40,6 +40,7 @@ void quisk_filt_cInit(struct quisk_cFilter *, double *, int);
 void quisk_filt_dInit(struct quisk_dFilter *, double *, int);
 void quisk_filt_tune(struct quisk_dFilter *, double, int);
 complex quisk_dC_out(double, struct quisk_dFilter *);
+double quisk_dD_out(double, struct quisk_dFilter *);
 int quisk_cInterpolate(complex *, int, struct quisk_cFilter *, int);
 int quisk_dInterpolate(double *, int, struct quisk_dFilter *, int);
 int quisk_cDecimate(complex *, int, struct quisk_cFilter *, int);
@@ -48,10 +49,12 @@ int quisk_cDecim2HB45(complex *, int, struct quisk_cHB45Filter *);
 int quisk_dInterp2HB45(double *, int, struct quisk_dHB45Filter *);
 int quisk_cInterp2HB45(complex *, int, struct quisk_cHB45Filter *);
 int quisk_dFilter(double *, int, struct quisk_dFilter *);
+int quisk_cFilter(complex *, int, struct quisk_cFilter *);
 
 extern double quiskMicFilt48Coefs[325];
+extern double quiskMic5Filt48Coefs[424];
 extern double quiskMicFilt8Coefs[93];
-extern double quiskLpFilt48Coefs[144];
+extern double quiskLpFilt48Coefs[186];
 extern double quiskFilt12_19Coefs[64];
 extern double quiskFilt185D3Coefs[188];
 extern double quiskFilt133D2Coefs[136];
@@ -67,3 +70,4 @@ extern double quiskAudio96Coefs[11];
 extern double quiskAudio24p4Coefs[47];
 extern double quiskAudioFmHpCoefs[309];
 extern double quiskAudio24p3Coefs[93];
+extern double quiskFiltTx8kAudioB[168];
