@@ -87,37 +87,45 @@ double quiskMicFilt8Coefs[93] = { -0.000048361334397216, -0.000162172832480051,
 -0.001395527281294679, -0.000533703037637750, 0.001010518676959113, 0.001852235322638049, 0.001555572669911020,
  0.000686150429731403, -0.000006327103457766, -0.000233937595698212, -0.000162172832480051, -0.000048361334397216} ;
 
-// Rate 48000, pass 3200, stop 4500, ripple 0.2 dB, atten 100 dB, taps 144. Stop .09375.
-double quiskLpFilt48Coefs[144] = {-0.000017125474330604, -0.000040011820393130, -0.000077862936583202,
--0.000127389313997705, -0.000181102741386044, -0.000225109758175834, -0.000239838685218700, -0.000202969232396477,
--0.000094305597311178, 0.000097794345082862, 0.000369998664433527, 0.000699241419612492, 0.001041511593601482,
- 0.001335775967586111, 0.001513363005661080, 0.001512024052854210, 0.001292282575245647, 0.000852402910741175,
- 0.000237845095399279, -0.000458531344106017, -0.001107710877113322, -0.001566990390963083, -0.001710431193735069,
--0.001461394216561484, -0.000819564995596107, 0.000125333340929399, 0.001199019317168316, 0.002169473500980469,
- 0.002792319280177214, 0.002866870662163649, 0.002290930866878644, 0.001100704907673480, -0.000516328530790399,
--0.002243035863158312, -0.003688859468654476, -0.004472285396379554, -0.004313484308907802, -0.003116141834256676,
--0.001017067737117166, 0.001613055660814351, 0.004224931456170525, 0.006196508693202270, 0.006971075945479586,
- 0.006198930990039089, 0.003849274053846188, 0.000261650017776247, -0.003883392014577992, -0.007678244207599024,
--0.010171159926985415, -0.010584341389004935, -0.008520924878120863, -0.004111405600230054, 0.001942089793582858,
- 0.008446987602879255, 0.013924611888810799, 0.016907513230850324, 0.016275537240591227, 0.011561878706483661,
- 0.003159517846795821, -0.007627342018415888, -0.018714786943998040, -0.027545855699856577, -0.031527533359270804,
--0.028522764468194239, -0.017305127467535198, 0.002115380882896933, 0.028367517836585164, 0.058831871715231798,
- 0.089984540025951881, 0.117919393961330910, 0.138960802368858470, 0.150258729900921100, 0.150258729900921100,
- 0.138960802368858470, 0.117919393961330910, 0.089984540025951881, 0.058831871715231798, 0.028367517836585164,
- 0.002115380882896933, -0.017305127467535198, -0.028522764468194239, -0.031527533359270804, -0.027545855699856577,
--0.018714786943998040, -0.007627342018415888, 0.003159517846795821, 0.011561878706483661, 0.016275537240591227,
- 0.016907513230850324, 0.013924611888810799, 0.008446987602879255, 0.001942089793582858, -0.004111405600230054,
--0.008520924878120863, -0.010584341389004935, -0.010171159926985415, -0.007678244207599024, -0.003883392014577992,
- 0.000261650017776247, 0.003849274053846188, 0.006198930990039089, 0.006971075945479586, 0.006196508693202270,
- 0.004224931456170525, 0.001613055660814351, -0.001017067737117166, -0.003116141834256676, -0.004313484308907802,
--0.004472285396379554, -0.003688859468654476, -0.002243035863158312, -0.000516328530790399, 0.001100704907673480,
- 0.002290930866878644, 0.002866870662163649, 0.002792319280177214, 0.002169473500980469, 0.001199019317168316,
- 0.000125333340929399, -0.000819564995596107, -0.001461394216561484, -0.001710431193735069, -0.001566990390963083,
--0.001107710877113322, -0.000458531344106017, 0.000237845095399279, 0.000852402910741175, 0.001292282575245647,
- 0.001512024052854210, 0.001513363005661080, 0.001335775967586111, 0.001041511593601482, 0.000699241419612492,
- 0.000369998664433527, 0.000097794345082862, -0.000094305597311178, -0.000202969232396477, -0.000239838685218700,
--0.000225109758175834, -0.000181102741386044, -0.000127389313997705, -0.000077862936583202, -0.000040011820393130,
--0.000017125474330604 } ;
+// Rate 48000, pass 3000, stop 4000, ripple 0.2 dB, atten 100 dB, taps 186. Stop .083333.
+double quiskLpFilt48Coefs[186] = { -0.000013634802929206, -0.000025833607451468, -0.000045098917291799,
+-0.000067397454184632, -0.000087934612849518, -0.000099336288085176, -0.000092164590568194, -0.000056185338095760,
+ 0.000017628479128830, 0.000134695138796130, 0.000294364688920149, 0.000487930816326543, 0.000697781352809774,
+ 0.000898146218636447, 0.001057686434085801, 0.001143917302878051, 0.001128977827853932, 0.000995827794007123,
+ 0.000743730207286422, 0.000391756255003027, -0.000020838483133667, -0.000438064704829056, -0.000794512795634084,
+-0.001025788840201078, -0.001080548087342285, -0.000932013104946299, -0.000586606665219995, -0.000087502631308000,
+ 0.000488407444073969, 0.001040518103766967, 0.001460541797297978, 0.001652270668043200, 0.001551661149061061,
+ 0.001143287935426198, 0.000469406269084863, -0.000371161499314815, -0.001235417370813682, -0.001958835103416428,
+-0.002385048283250022, -0.002397529299276367, -0.001947179493277411, -0.001069838763968274, 0.000110976961796973,
+ 0.001398395929344110, 0.002552691150332272, 0.003333738458450593, 0.003548332671239537, 0.003093481207411224,
+ 0.001986606612550283, 0.000375208969545557, -0.001478173505667034, -0.003235390501589682, -0.004541286966345233,
+-0.005091921692691575, -0.004699905483508720, -0.003343628882412480, -0.001188973425908869, 0.001423632771579898,
+ 0.004027852785840577, 0.006109889449352044, 0.007204411806930103, 0.006990964143613923, 0.005372067993842730,
+ 0.002515924626355224, -0.001148191299404085, -0.004985775758010277, -0.008258611238961837, -0.010257070307501979,
+-0.010440987284724979, -0.008563091952746314, -0.004749779955204285, 0.000480411506971036, 0.006270496250094757,
+ 0.011548336869209398, 0.015203957673842774, 0.016294017929596276, 0.014239284159958419, 0.008979207551576943,
+ 0.001052260094328930, -0.008418875271295619, -0.017843305879886966, -0.025368239712008800, -0.029148572862344568,
+-0.027640215600942798, -0.019871118305655480, -0.005644876301707345, 0.014359687674705773, 0.038614566536650477,
+ 0.064896650800270142, 0.090551963489257925, 0.112834114097579010, 0.129268306000616030, 0.137987044444314420,
+ 0.137987044444314420, 0.129268306000616030, 0.112834114097579010, 0.090551963489257925, 0.064896650800270142,
+ 0.038614566536650477, 0.014359687674705773, -0.005644876301707345, -0.019871118305655480, -0.027640215600942798,
+-0.029148572862344568, -0.025368239712008800, -0.017843305879886966, -0.008418875271295619, 0.001052260094328930,
+ 0.008979207551576943, 0.014239284159958419, 0.016294017929596276, 0.015203957673842774, 0.011548336869209398,
+ 0.006270496250094757, 0.000480411506971036, -0.004749779955204285, -0.008563091952746314, -0.010440987284724979,
+-0.010257070307501979, -0.008258611238961837, -0.004985775758010277, -0.001148191299404085, 0.002515924626355224,
+ 0.005372067993842730, 0.006990964143613923, 0.007204411806930103, 0.006109889449352044, 0.004027852785840577,
+ 0.001423632771579898, -0.001188973425908869, -0.003343628882412480, -0.004699905483508720, -0.005091921692691575,
+-0.004541286966345233, -0.003235390501589682, -0.001478173505667034, 0.000375208969545557, 0.001986606612550283,
+ 0.003093481207411224, 0.003548332671239537, 0.003333738458450593, 0.002552691150332272, 0.001398395929344110,
+ 0.000110976961796973, -0.001069838763968274, -0.001947179493277411, -0.002397529299276367, -0.002385048283250022,
+-0.001958835103416428, -0.001235417370813682, -0.000371161499314815, 0.000469406269084863, 0.001143287935426198,
+ 0.001551661149061061, 0.001652270668043200, 0.001460541797297978, 0.001040518103766967, 0.000488407444073969,
+-0.000087502631308000, -0.000586606665219995, -0.000932013104946299, -0.001080548087342285, -0.001025788840201078,
+-0.000794512795634084, -0.000438064704829056, -0.000020838483133667, 0.000391756255003027, 0.000743730207286422,
+ 0.000995827794007123, 0.001128977827853932, 0.001143917302878051, 0.001057686434085801, 0.000898146218636447,
+ 0.000697781352809774, 0.000487930816326543, 0.000294364688920149, 0.000134695138796130, 0.000017628479128830,
+-0.000056185338095760, -0.000092164590568194, -0.000099336288085176, -0.000087934612849518, -0.000067397454184632,
+-0.000045098917291799, -0.000025833607451468, -0.000013634802929206 } ;
 
 // Sample 1 Hz, pass 0.125, stop 0.192, ripple 0.1 dB, atten 100 dB, taps 64.  Stop 0.192.
 double quiskFilt12_19Coefs[64] = { 0.000043810351462319, 0.000138863869398690, 0.000206835545025070,
@@ -687,3 +695,126 @@ double quiskFilt167D3Coefs[173] = { 0.000027361057967466, 0.000079022927580003,
  0.000431036292372644, 0.000087636155699997, -0.000391274475742801, -0.000778111000786101, -0.000919092591781850,
 -0.000792207008833313, -0.000490420382204739, -0.000154926195574306, 0.000097396424148557, 0.000216051711988195,
  0.000217036303406228, 0.000153315280214681, 0.000079022927580003, 0.000027361057967466 } ;
+
+// Sample 8000 Hz, stop 0 to 120, pass 300 to 2700, stop 2900 to 4000, ripple 0.1dB, atten 100 dB.
+double quiskFiltTx8kAudioB[168] = { 0.000382863369135811, 0.001125903700328483, 0.000925837447276999, -0.000374734941094989,
+-0.000888985517068820, -0.000361216817648551, -0.000190964056763804, -0.000521640215250387, -0.000810984560171181,
+-0.000586556150016652, -0.000283591051604510, -0.000870238259790123, -0.000852903625374087, 0.000024159967210229,
+-0.000630232168612451, -0.000785665131620066, 0.000569610938158391, -0.000138017351197930, -0.000362220277410620,
+ 0.001366339327936554, 0.000470327395373754, 0.000284347316273074, 0.002255344271539108, 0.000942593074105167,
+ 0.000895615209137272, 0.002941734992852122, 0.000961093640197151, 0.001177319952191160, 0.003099108113624071,
+ 0.000249508373597955, 0.000915783375976514, 0.002501346935887695, -0.001290867165414506, 0.000106788350951055,
+ 0.001148919726851922, -0.003476112709865105, -0.000973631179709113, -0.000674076242033701, -0.005811280332409654,
+-0.001784274911171613, -0.002440004582391299, -0.007574097052077259, -0.001651967564004321, -0.003534348839131837,
+-0.008009304387660080, 0.000005086297602882, -0.003482125314769407, -0.006580016297377269, 0.003414827979152467,
+-0.002192304121179012, -0.003207666910599826, 0.008239448308648542, -0.000120276288831242, 0.001601392930489681,
+ 0.013506207426436229, 0.001723883024608883, 0.006793369654665180, 0.017715945730523756, 0.001956966866997749,
+ 0.011004187010827985, 0.019134477971688185, -0.000836412988146811, 0.012945050783659821, 0.016195220864669575,
+-0.007677125676925340, 0.011863897915831447, 0.007909156115753185, -0.018792331215007903, 0.007957114843116177,
+-0.005919014059116164, -0.033405211299572850, 0.002675271476407882, -0.024817610540172161, -0.049749838513716206,
+-0.000915002981442826, -0.048502552862820653, -0.065383587718200784, 0.003175445066804758, -0.080194918286764838,
+-0.077682133405468937, 0.033727063680071466, -0.150760186145271510, -0.084457338944868982, 0.505660603990009560,
+ 0.505660603990009560, -0.084457338944868982, -0.150760186145271510, 0.033727063680071466, -0.077682133405468937,
+-0.080194918286764838, 0.003175445066804758, -0.065383587718200784, -0.048502552862820653, -0.000915002981442826,
+-0.049749838513716206, -0.024817610540172161, 0.002675271476407882, -0.033405211299572850, -0.005919014059116164,
+ 0.007957114843116177, -0.018792331215007903, 0.007909156115753185, 0.011863897915831447, -0.007677125676925340,
+ 0.016195220864669575, 0.012945050783659821, -0.000836412988146811, 0.019134477971688185, 0.011004187010827985,
+ 0.001956966866997749, 0.017715945730523756, 0.006793369654665180, 0.001723883024608883, 0.013506207426436229,
+ 0.001601392930489681, -0.000120276288831242, 0.008239448308648542, -0.003207666910599826, -0.002192304121179012,
+ 0.003414827979152467, -0.006580016297377269, -0.003482125314769407, 0.000005086297602882, -0.008009304387660080,
+-0.003534348839131837, -0.001651967564004321, -0.007574097052077259, -0.002440004582391299, -0.001784274911171613,
+-0.005811280332409654, -0.000674076242033701, -0.000973631179709113, -0.003476112709865105, 0.001148919726851922,
+ 0.000106788350951055, -0.001290867165414506, 0.002501346935887695, 0.000915783375976514, 0.000249508373597955,
+ 0.003099108113624071, 0.001177319952191160, 0.000961093640197151, 0.002941734992852122, 0.000895615209137272,
+ 0.000942593074105167, 0.002255344271539108, 0.000284347316273074, 0.000470327395373754, 0.001366339327936554,
+-0.000362220277410620, -0.000138017351197930, 0.000569610938158391, -0.000785665131620066, -0.000630232168612451,
+ 0.000024159967210229, -0.000852903625374087, -0.000870238259790123, -0.000283591051604510, -0.000586556150016652,
+-0.000810984560171181, -0.000521640215250387, -0.000190964056763804, -0.000361216817648551, -0.000888985517068820,
+-0.000374734941094989, 0.000925837447276999, 0.001125903700328483, 0.000382863369135811 } ;
+// Sample 48000 Hz, pass 2350, stop 2650, ripple 1 dB, atten 80 dB.  Stop 0.05521.
+double quiskMic5Filt48Coefs[424] = {
+-0.000087601196745517, -0.000119178480453066, -0.000192494530734137, -0.000287398500897765, -0.000404455107555149,
+-0.000542187350923721, -0.000697354821092750, -0.000864361814542882, -0.001035675409027330, -0.001201670675683178,
+-0.001351260760102592, -0.001472389090721280, -0.001552963425946309, -0.001581622501567850, -0.001548788902291486,
+-0.001447577149496593, -0.001274757191818737, -0.001031365182705646, -0.000723138798454071, -0.000360540808884225,
+ 0.000041472210381792, 0.000464151153253057, 0.000885978417045319, 0.001284080850383070, 0.001635786964228304,
+ 0.001920322587244723, 0.002120431736364362, 0.002223894227313585, 0.002224702189457267, 0.002123834204231122,
+ 0.001929455560771270, 0.001656578667677397, 0.001326124950893504, 0.000963492246325779, 0.000596656779876184,
+ 0.000254003709475283, -0.000037984405595945, -0.000256935860609037, -0.000386544706976665, -0.000418046328997344,
+-0.000351100298847373, -0.000193939445451714, 0.000037212952694738, 0.000319460819342812, 0.000625164037239141,
+ 0.000924363583767082, 0.001187470307244314, 0.001388000318914036, 0.001505069987035192, 0.001525437805536890,
+ 0.001444870661224978, 0.001268714805496182, 0.001011568778937986, 0.000696080786323511, 0.000350937369521106,
+ 0.000008234786560396, -0.000299551487706380, -0.000542701008001189, -0.000697204883792079, -0.000747233312787443,
+-0.000686876298204384, -0.000520952456912102, -0.000264798296929030, 0.000056986807722520, 0.000412734842368625,
+ 0.000766669398901066, 0.001082346669587512, 0.001326263088537886, 0.001471265194417923, 0.001499431895309172,
+ 0.001404113830652116, 0.001190910569750263, 0.000877443544384873, 0.000491924577078300, 0.000070618732748754,
+-0.000345567500376679, -0.000715070316355716, -0.000999834598355945, -0.001169257920406941, -0.001203497801923855,
+-0.001095797960360223, -0.000853559853825754, -0.000498020971159122, -0.000062520041312805, 0.000410511052497376,
+ 0.000873571510876301, 0.001278748950006680, 0.001582567444665569, 0.001750535054942567, 0.001760927137558775,
+ 0.001607388781175447, 0.001300061195708352, 0.000865065069005933, 0.000342348399080757, -0.000217942303300231,
+-0.000760241586711499, -0.001229053244090960, -0.001574604672635160, -0.001758102209059370, -0.001756034066558804,
+-0.001563058384174837, -0.001193131136885269, -0.000678706705799908, -0.000068024295664869, 0.000579300435978082,
+ 0.001197989750585395, 0.001723580332124720, 0.002099032072900320, 0.002280794678156941, 0.002243699390601673,
+ 0.001984133400353534, 0.001521121064322945, 0.000895127993320633, 0.000164637922390302, -0.000599227139535745,
+-0.001319555291352399, -0.001921314886803284, -0.002339087231340391, -0.002524079501171732, -0.002449675079358536,
+-0.002114908771525688, -0.001545437314172064, -0.000791823925944463, 0.000074782605168353, 0.000969218460672265,
+ 0.001800534718138737, 0.002481100933662590, 0.002935686794045762, 0.003109591237339856, 0.002974959532860613,
+ 0.002534577733743369, 0.001822671724082916, 0.000902520745944448, -0.000138980947793396, -0.001199369993895262,
+-0.002170536435942518, -0.002949581024448342, -0.003449532389579513, -0.003608829916851618, -0.003398558758097474,
+-0.002826619977722426, -0.001938296425724648, -0.000813026544735210, 0.000442428219163585, 0.001703859853903780,
+ 0.002841646272526556, 0.003733795631607910, 0.004278716742047143, 0.004406405339454943, 0.004086851240208961,
+ 0.003334703369161471, 0.002209574959936082, 0.000811784328342671, -0.000726216440571004, -0.002252031018207481,
+-0.003608037091401704, -0.004647249273905110, -0.005248768326240763, -0.005331240183248048, -0.004862881229352157,
+-0.003866915473379464, -0.002421678784759232, -0.000655151171295565, 0.001265777761167976, 0.003150462759634698,
+ 0.004802753890816374, 0.006040653489191535, 0.006715477432817280, 0.006728582425712883, 0.006043878643663059,
+ 0.004694681402232655, 0.002783951074178680, 0.000477576037627513, -0.002008976414542753, -0.004429653284750409,
+-0.006530865070729735, -0.008076534379704757, -0.008872792811204462, -0.008789897699281934, -0.007779088447247421,
+-0.005882478096374164, -0.003234645557614322, -0.000055318960121547, 0.003366648103157717, 0.006696974329608038,
+ 0.009585521827024799, 0.011699303862532495, 0.012756057470065627, 0.012555316826801740, 0.011004006112499458,
+ 0.008133925792679506, 0.004109116367295407, -0.000778103172178875, -0.006122670687011962, -0.011433128819157286,
+-0.016167043119046529, -0.019772887723249422, -0.021735132723275978, -0.021618869254173001, -0.019110214094446909,
+-0.014048964546840230, -0.006450511384232603, 0.003485174039118999, 0.015378649609086421, 0.028690243785521201,
+ 0.042752300360393465, 0.056812206812071039, 0.070083061994479681, 0.081798161497452851, 0.091265110934848792,
+ 0.097915351884672430, 0.101345208406692710, 0.101345208406692710, 0.097915351884672430, 0.091265110934848792,
+ 0.081798161497452851, 0.070083061994479681, 0.056812206812071039, 0.042752300360393465, 0.028690243785521201,
+ 0.015378649609086421, 0.003485174039118999, -0.006450511384232603, -0.014048964546840230, -0.019110214094446909,
+-0.021618869254173001, -0.021735132723275978, -0.019772887723249422, -0.016167043119046529, -0.011433128819157286,
+-0.006122670687011962, -0.000778103172178875, 0.004109116367295407, 0.008133925792679506, 0.011004006112499458,
+ 0.012555316826801740, 0.012756057470065627, 0.011699303862532495, 0.009585521827024799, 0.006696974329608038,
+ 0.003366648103157717, -0.000055318960121547, -0.003234645557614322, -0.005882478096374164, -0.007779088447247421,
+-0.008789897699281934, -0.008872792811204462, -0.008076534379704757, -0.006530865070729735, -0.004429653284750409,
+-0.002008976414542753, 0.000477576037627513, 0.002783951074178680, 0.004694681402232655, 0.006043878643663059,
+ 0.006728582425712883, 0.006715477432817280, 0.006040653489191535, 0.004802753890816374, 0.003150462759634698,
+ 0.001265777761167976, -0.000655151171295565, -0.002421678784759232, -0.003866915473379464, -0.004862881229352157,
+-0.005331240183248048, -0.005248768326240763, -0.004647249273905110, -0.003608037091401704, -0.002252031018207481,
+-0.000726216440571004, 0.000811784328342671, 0.002209574959936082, 0.003334703369161471, 0.004086851240208961,
+ 0.004406405339454943, 0.004278716742047143, 0.003733795631607910, 0.002841646272526556, 0.001703859853903780,
+ 0.000442428219163585, -0.000813026544735210, -0.001938296425724648, -0.002826619977722426, -0.003398558758097474,
+-0.003608829916851618, -0.003449532389579513, -0.002949581024448342, -0.002170536435942518, -0.001199369993895262,
+-0.000138980947793396, 0.000902520745944448, 0.001822671724082916, 0.002534577733743369, 0.002974959532860613,
+ 0.003109591237339856, 0.002935686794045762, 0.002481100933662590, 0.001800534718138737, 0.000969218460672265,
+ 0.000074782605168353, -0.000791823925944463, -0.001545437314172064, -0.002114908771525688, -0.002449675079358536,
+-0.002524079501171732, -0.002339087231340391, -0.001921314886803284, -0.001319555291352399, -0.000599227139535745,
+ 0.000164637922390302, 0.000895127993320633, 0.001521121064322945, 0.001984133400353534, 0.002243699390601673,
+ 0.002280794678156941, 0.002099032072900320, 0.001723580332124720, 0.001197989750585395, 0.000579300435978082,
+-0.000068024295664869, -0.000678706705799908, -0.001193131136885269, -0.001563058384174837, -0.001756034066558804,
+-0.001758102209059370, -0.001574604672635160, -0.001229053244090960, -0.000760241586711499, -0.000217942303300231,
+ 0.000342348399080757, 0.000865065069005933, 0.001300061195708352, 0.001607388781175447, 0.001760927137558775,
+ 0.001750535054942567, 0.001582567444665569, 0.001278748950006680, 0.000873571510876301, 0.000410511052497376,
+-0.000062520041312805, -0.000498020971159122, -0.000853559853825754, -0.001095797960360223, -0.001203497801923855,
+-0.001169257920406941, -0.000999834598355945, -0.000715070316355716, -0.000345567500376679, 0.000070618732748754,
+ 0.000491924577078300, 0.000877443544384873, 0.001190910569750263, 0.001404113830652116, 0.001499431895309172,
+ 0.001471265194417923, 0.001326263088537886, 0.001082346669587512, 0.000766669398901066, 0.000412734842368625,
+ 0.000056986807722520, -0.000264798296929030, -0.000520952456912102, -0.000686876298204384, -0.000747233312787443,
+-0.000697204883792079, -0.000542701008001189, -0.000299551487706380, 0.000008234786560396, 0.000350937369521106,
+ 0.000696080786323511, 0.001011568778937986, 0.001268714805496182, 0.001444870661224978, 0.001525437805536890,
+ 0.001505069987035192, 0.001388000318914036, 0.001187470307244314, 0.000924363583767082, 0.000625164037239141,
+ 0.000319460819342812, 0.000037212952694738, -0.000193939445451714, -0.000351100298847373, -0.000418046328997344,
+-0.000386544706976665, -0.000256935860609037, -0.000037984405595945, 0.000254003709475283, 0.000596656779876184,
+ 0.000963492246325779, 0.001326124950893504, 0.001656578667677397, 0.001929455560771270, 0.002123834204231122,
+ 0.002224702189457267, 0.002223894227313585, 0.002120431736364362, 0.001920322587244723, 0.001635786964228304,
+ 0.001284080850383070, 0.000885978417045319, 0.000464151153253057, 0.000041472210381792, -0.000360540808884225,
+-0.000723138798454071, -0.001031365182705646, -0.001274757191818737, -0.001447577149496593, -0.001548788902291486,
+-0.001581622501567850, -0.001552963425946309, -0.001472389090721280, -0.001351260760102592, -0.001201670675683178,
+-0.001035675409027330, -0.000864361814542882, -0.000697354821092750, -0.000542187350923721, -0.000404455107555149,
+-0.000287398500897765, -0.000192494530734137, -0.000119178480453066, -0.000087601196745517} ;
