@@ -41,14 +41,17 @@ int mic_max_display;			// display value of maximum microphone signal level 0 to
 
 static int mic_socket = INVALID_SOCKET;	// send microphone samples to a socket
 static int spotLevel = 0;				// 0 for no spotting; else the level 10 to 1000
-static double mic_avg_gain = 10.0;		// Typical gain for the microphone in use
-static double mic_max_gain = 100.0;		// Do not increase gain over this value
+static double mic_min_level = 0.10;		// Mic levels below this are noise and are ignored
 
 static int mic_level;			// maximum microphone signal level for display
 static int mic_timer;			// time to display maximum mic level
 static int align4;			// add two bytes to start of audio samples to align to 4 bytes
 static double modulation_index = 1.6;	// For FM transmit, the modulation index
 
+static int is_vox = 0;					// Is the VOX level exceeded?
+static int vox_level = CLIP16;			// VOX trigger level as a number 0 to CLIP16
+static int timeVOX = 2000;				// VOX hang time in milliseconds
+
 #define TX_BLOCK_SHORTS		600		// transmit UDP packet with this many shorts (two bytes) (perhaps + 1)
 #define MIC_MAX_HOLD_TIME	400		// Time to hold the maximum mic level on the Status screen in milliseconds
 
@@ -181,170 +184,315 @@ static void get_2tone(complex * cSamples, int count)
 }
 #endif
 
-static int tx_filter(complex * filtered, int count, int is_cpx)
-{	// Input samples are creal(filtered), output is filtered.
-	// For is_cpx == 1, output is SSB I/Q samples; else output is creal(filtered) sound.
-	int i;
-	double dsample, x, dtmp, peakA, gain, amplitude;
+static double CcmPeak(double * dsamples, complex * csamples, int count)
+{
+	int i, j;
 	complex csample;
+	double dtmp, dsample, newlevel, oldlevel;
+	static double out_short, out_long;
+	static struct Ccmpr {
+		int buf_size;
+		int index_read;
+		double themax;
+		double level;
+		double * d_samp;
+		complex * c_samp;
+		double * levl;
+	} dat = {0};
 
-	static double x_1 = 0;
-	static double gainA = 10.0, gainB = 0.8;
-	static double time_short, time_long;
-	static struct quisk_dFilter filter1={NULL}, filter2;
-	static struct quisk_cFilter filtDecim, filtInterp;
-	static int mic_interp, mic_decim, sample_rate;
-#if DEBUG_IO
-	static double peakIn = 0, peakOut1 = 0, peakOut2 = 0, peakOut3 = 0;	// input/output level
-#endif
-	if (!filtered) {		// initialization
-        gainA = mic_avg_gain;
-		if (! filter1.dCoefs) {
-			if (quisk_sound_state.mic_sample_rate == 8000) {
-				sample_rate = 8000;
-				mic_decim = 1;
-				mic_interp = MIC_OUT_RATE / sample_rate;
-				quisk_filt_dInit(&filter1, quiskMicFilt8Coefs, sizeof(quiskMicFilt8Coefs)/sizeof(double));
-				quisk_filt_dInit(&filter2, quiskMicFilt8Coefs, sizeof(quiskMicFilt8Coefs)/sizeof(double));
-				quisk_filt_cInit(&filtInterp, quiskLpFilt48Coefs, sizeof(quiskLpFilt48Coefs)/sizeof(double));
-			}
-			else if (DECIM_8000) {		// decimate 48000 to 8000 sps
-				sample_rate = 8000;
-				mic_decim = mic_interp = MIC_OUT_RATE / sample_rate;
-				quisk_filt_dInit(&filter1, quiskMicFilt8Coefs, sizeof(quiskMicFilt8Coefs)/sizeof(double));
-				quisk_filt_dInit(&filter2, quiskMicFilt8Coefs, sizeof(quiskMicFilt8Coefs)/sizeof(double));
-				quisk_filt_cInit(&filtDecim, quiskLpFilt48Coefs, sizeof(quiskLpFilt48Coefs)/sizeof(double));
-				quisk_filt_cInit(&filtInterp, quiskLpFilt48Coefs, sizeof(quiskLpFilt48Coefs)/sizeof(double));
-			}
-			else {		// process at 48000 sps
-				sample_rate = 48000;
-				mic_decim = mic_interp = MIC_OUT_RATE / sample_rate;
-				quisk_filt_dInit(&filter1, quiskMicFilt48Coefs, sizeof(quiskMicFilt48Coefs)/sizeof(double));
-				quisk_filt_dInit(&filter2, quiskMicFilt48Coefs, sizeof(quiskMicFilt48Coefs)/sizeof(double));
+	if ( ! dat.buf_size) {		// initialize; the sample rate is 8000
+		dat.buf_size = 8000 * 30 / 1000;	// total delay in samples
+		dat.index_read = 0;					// index to output; and then write a new sample here
+		dat.themax = 1.0;					// maximum level in the buffer
+		dat.level = 1.0;					// current output level
+		dat.d_samp = (double *) malloc(dat.buf_size * sizeof(double));		// buffer for double samples
+		dat.c_samp = (complex *) malloc(dat.buf_size * sizeof(complex));	// buffer for complex samples
+		dat.levl = (double *) malloc(dat.buf_size * sizeof(double));		// magnitude of the samples
+		for (i = 0; i < dat.buf_size; i++) {
+			dat.d_samp[i] = 0;
+			dat.c_samp[i] = 0;
+			dat.levl[i] = 1.0;
+		}
+		dtmp = 1.0 / 8000;		// sample time
+		out_short  = 1.0 - exp(- dtmp / 0.010);		// short time constant
+		out_long   = 1.0 - exp(- dtmp / 3.000);		// long time constant
+		return 1.0;
+	}
+	for (i = 0; i < count; i++) {
+		if (dsamples) {
+			dsample = dsamples[i];
+			dsamples[i] = dat.d_samp[dat.index_read] / dat.level;	// FIFO output
+			dat.d_samp[dat.index_read] = dsample;		// write new sample at read index
+			newlevel = fabs(dsample);
+		}
+		else {
+			csample = csamples[i];
+			csamples[i] = dat.c_samp[dat.index_read] / dat.level;	// FIFO output
+			dat.c_samp[dat.index_read] = csample;		// write new sample at read index
+			newlevel = cabs(csample);
+		}
+		oldlevel = dat.levl[dat.index_read];
+		dat.levl[dat.index_read] = newlevel;
+		if (newlevel < dat.themax && oldlevel < dat.themax) {		// some other sample is the maximum
+			// no change to dat.themax
+		}
+		else if (newlevel > dat.themax && newlevel > oldlevel) {	// newlevel is the maximum
+			dat.themax = newlevel;
+		}
+		else {		// search for the maximum level
+			dat.themax = 0;		// Find the maximim level in the buffer
+			for (j = 0; j < dat.buf_size; j++) {
+				if (dat.levl[j] > dat.themax)
+					dat.themax = dat.levl[j];
 			}
 		}
-		dtmp = 1.0 / sample_rate;		// sample time
-		time_short = 1.0 - exp(- dtmp /  0.010);
-		time_long  = 1.0 - exp(- dtmp / 10.000);
-		quisk_filt_tune(&filter1, 1650.0 / sample_rate, rxMode != 2);
-		quisk_filt_tune(&filter2, 1650.0 / sample_rate, rxMode != 2);
+// Increase dat.level if the maximum level is greater than 1.0;
+// decrease it slowly back to 1.0 if it is lower.  Output is modulated by dat.level.
+		if (dat.themax > 1.0)	// increase rapidly to the peak level
+			dat.level = dat.level * (1.0 - out_short) + dat.themax * out_short;
+		else				// decrease slowly back to 1.0
+			dat.level = dat.level * (1.0 - out_long) + 1.0 * out_long;
+		if (++dat.index_read >= dat.buf_size)
+			dat.index_read = 0;
+	}
+	return dat.level;
+}
+
+static int tx_filter(complex * filtered, int count)
+{	// Input samples are creal(filtered), output is filtered.  The input rate must be 8000 or 48000 sps.
+	int i, is_ssb;
+	int sample_rate = 8000;
+	double dsample, dtmp, magn;
+	complex csample;
+	static double inMax=0.3;
+	static double x_1=0;
+	static double aaa, bbb, ccc, Xmin, Xmax, Ymax;
+    static int samples_size = 0;
+    static double * dsamples = NULL;
+	static complex * csamples = NULL;
+	static double time_long, time_short;
+	static struct quisk_dFilter filtDecim, dfiltInterp;
+	static struct quisk_dFilter filtAudio1, filtAudio2, dfiltAudio3;
+	static struct quisk_cFilter cfiltAudio3, cfiltInterp;
+	static struct quisk_dFilter filter1={NULL}, filter2;
+#if DEBUG_IO
+	char * clip;
+	static double dbOut = 0, Level0 = 0, Level1 = 0, Level2 = 0, Level3 = 0, Level4 = 0;
+#endif
+	is_ssb = (rxMode == 2 || rxMode == 3);
+	if (!filtered) {		// initialization
+		if (! filter1.dCoefs) {
+			quisk_filt_dInit(&filter1, quiskMicFilt8Coefs, sizeof(quiskMicFilt8Coefs)/sizeof(double));
+			quisk_filt_dInit(&filter2, quiskMicFilt8Coefs, sizeof(quiskMicFilt8Coefs)/sizeof(double));
+			quisk_filt_dInit(&filtDecim,  quiskLpFilt48Coefs, sizeof(quiskLpFilt48Coefs)/sizeof(double));
+			quisk_filt_dInit(&dfiltInterp, quiskLpFilt48Coefs, sizeof(quiskLpFilt48Coefs)/sizeof(double));
+			quisk_filt_cInit(&cfiltInterp, quiskLpFilt48Coefs, sizeof(quiskLpFilt48Coefs)/sizeof(double));
+			quisk_filt_dInit(&filtAudio1, quiskFiltTx8kAudioB, sizeof(quiskFiltTx8kAudioB)/sizeof(double));
+			quisk_filt_dInit(&filtAudio2, quiskFiltTx8kAudioB, sizeof(quiskFiltTx8kAudioB)/sizeof(double));
+			quisk_filt_dInit(&dfiltAudio3, quiskFiltTx8kAudioB, sizeof(quiskFiltTx8kAudioB)/sizeof(double));
+			quisk_filt_cInit(&cfiltAudio3, quiskFiltTx8kAudioB, sizeof(quiskFiltTx8kAudioB)/sizeof(double));
+			dtmp = 1.0 / sample_rate;		// sample time
+			time_long   = 1.0 - exp(- dtmp / 3.000);
+			time_short  = 1.0 - exp(- dtmp / 0.005);
+			Ymax = pow(10.0,  - 1 / 20.0);				// maximum y
+			Xmax = pow(10.0,  3 / 20.0);				// x where slope is zero; for x > Xmax, y == Ymax
+			Xmin = Ymax - fabs(Ymax - Xmax);		// x where slope is 1 and y = x; start of compression
+			aaa = 1.0 / (2.0 * (Xmin - Xmax));		// quadratic
+			bbb = -2.0 * aaa * Xmax;
+			ccc = Ymax - aaa * Xmax * Xmax - bbb * Xmax;
+#if DEBUG_IO
+			printf("Compress to %.2lf dB from %.2lf to %.2lf dB\n",
+				20 * log10(Ymax), 20 * log10(Xmin), 20 * log10(Xmax));
+#endif
+		}
+		if (is_ssb) {
+		  quisk_filt_tune(&filter1, 1650.0 / sample_rate, rxMode != 2);
+		  quisk_filt_tune(&filter2, 1650.0 / sample_rate, rxMode != 2);
+		}
 		return 0;
 	}
+	// check size of dsamples[] and csamples[] buffer
+    if (count > samples_size) {
+        samples_size = count * 2;
+        if (dsamples)
+            free(dsamples);
+        if (csamples)
+            free(csamples);
+        dsamples = (double *)malloc(samples_size * sizeof(double));
+        csamples = (complex *)malloc(samples_size * sizeof(complex));
+    }
+	// copy to dsamples[], normalize to +/- 1.0
+	for (i = 0; i < count; i++)
+		dsamples[i] = creal(filtered[i]) / CLIP16;
+	// Decimate to 8000 Hz
+	if (quisk_sound_state.mic_sample_rate != sample_rate)
+		count = quisk_dDecimate(dsamples, count, &filtDecim, quisk_sound_state.mic_sample_rate / sample_rate);
+	// restrict bandwidth 300 to 2700 Hz
+	count = quisk_dFilter(dsamples, count, &filtAudio1);
 #if DEBUG_IO
-	//QuiskPrintTime("", -2);
-#endif
-	if (mic_decim > 1)
-		count = quisk_cDecimate(filtered, count, &filtDecim, mic_decim);
-	peakA = 1E-6;
+	// Measure peak input audio level
 	for (i = 0; i < count; i++) {
-		dsample = creal(filtered[i]) / CLIP16;		// normalize to +/- 1.0
+		magn = fabs(dsamples[i]);
+		if (magn > Level0)
+			Level0 = magn;
+	}
+#endif
+	// high pass filter for preemphasis: See Radcom, January 2010, page 76.
+	// quisk_mic_preemphasis == 1 was measured as 6 dB / octave.
+	// gain at 800 Hz was measured as 0.104672.
+	for (i = 0; i < count; i++) {
+		dtmp = dsamples[i];
+		dsamples[i] = dtmp - quisk_mic_preemphasis * x_1;
+		x_1 = dtmp;	// delayed sample
+		dsamples[i] *= 2;		// compensate for loss
 #if DEBUG_IO
-		x = fabs(dsample);
-		if (x > peakIn)
-			peakIn = x;
+		magn = fabs(dsamples[i]);
+		if (magn > Level1)
+			Level1 = magn;
 #endif
-#if 1
-		// high pass filter for preemphasis: See Radcom, January 2010, page 76.
-		// quisk_mic_preemphasis == 1 was measured as 6 dB / octave.
-		// gain at 800 Hz was measured as 0.104672.
-		x = dsample;
-		dsample = x - quisk_mic_preemphasis * x_1;
-		x_1 = x;	// delayed sample
-#endif
-#if 1
+	}
+	if (is_ssb) {	// SSB
 		// FIR bandpass filter; separate into I and Q
-		csample = quisk_dC_out(dsample, &filter1);
-#endif
-#if 1
-		// Audio compression. The desired output level is quisk_mic_clip / 2.5.
-		dtmp = cabs(csample);
-		if (dtmp != 0) {
-			gain = quisk_mic_clip / 2.5 / dtmp;	// target gain
-			if (gain > mic_max_gain)
-				gain = mic_max_gain;
-			if (gainA > gain)
-				gainA = gainA * (1 - time_short) + time_short * gain;	// gainA too high
+		for (i = 0; i < count; i++) {
+			csample = quisk_dC_out(dsamples[i], &filter1);
+			// Measure average peak input audio level and normalize
+			magn = cabs(csample);
+			if (magn > inMax)
+				inMax = inMax * (1 - time_short) + time_short * magn;
+			else if(magn > mic_min_level)
+				inMax = inMax * (1 - time_long) + time_long * magn;
 			else
-				gainA = gainA * (1 - time_long) + time_long * gain;	// gainA too low
-		}
-		csample *= gainA;
-#endif
+				inMax = inMax * (1 - time_long) + time_long * mic_min_level;
+			csample /= inMax;
+			magn /= inMax;
 #if DEBUG_IO
-		x = cabs(csample);
-		if (x > peakOut1)
-			peakOut1 = x;
+			if (magn > Level2)
+				Level2 = magn;
 #endif
-#if 1
-		// Clip signal at the level 1.0
-		dtmp = cabs(csample);
-		if (dtmp > 1.0)
-			csample = csample / dtmp;
+			// Audio compression.
+			csample *= quisk_mic_clip;
+			magn *= quisk_mic_clip;
+			if (magn > 1.0)
+				csample = csample / magn;
+			dsamples[i] = creal(csample);
+		}
+	}
+	else {		// AM and FM
+		// Measure average peak input audio level and normalize
+		for (i = 0; i < count; i++) {
+			dsample = dsamples[i];
+			magn = fabs(dsample);
+			if (magn > inMax)
+				inMax = inMax * (1 - time_short) + time_short * magn;
+			else if(magn > mic_min_level)
+				inMax = inMax * (1 - time_long) + time_long * magn;
+			else
+				inMax = inMax * (1 - time_long) + time_long * mic_min_level;
+			dsample /= inMax;
+			magn /= inMax;
+#if DEBUG_IO
+			if (magn > Level2)
+				Level2 = magn;
 #endif
-#if 1
+		// Audio compression.
+			dsample *= quisk_mic_clip;
+			magn *= quisk_mic_clip;
+			if (magn < Xmin)
+				dsamples[i] = dsample;
+			else if (magn > Xmax)
+				dsamples[i] = copysign(Ymax, dsample);
+			else
+				dsamples[i] = copysign(aaa * magn * magn + bbb * magn + ccc, dsample);
+		}
+	}
+	// remove clipping distortion; restrict bandwidth 300 to 2700 Hz
+	count = quisk_dFilter(dsamples, count, &filtAudio2);
+	if (is_ssb) {	// SSB
 		// FIR bandpass filter; separate into I and Q
-		csample = quisk_dC_out(creal(csample), &filter2);
-#endif
-		if (is_cpx) {
-			amplitude = cabs(csample);
-		}
-		else {		// convert to real samples
-			dtmp = creal(csample);
-			csample = dtmp;
-			amplitude = fabs(dtmp);
-		}
-		if (amplitude > peakA)
-			peakA = amplitude;
+		for (i = 0; i < count; i++) {
+			csamples[i] = quisk_dC_out(creal(dsamples[i]), &filter2);
 #if DEBUG_IO
-		if (amplitude > peakOut2)
-			peakOut2 = amplitude;
+			magn = cabs(csamples[i]);
+			if (magn > Level3)
+				Level3 = magn;
 #endif
-		filtered[i] = csample;
-	}
-	// Normalize final amplitude based on the peak
-	dtmp = (double)count / sample_rate;		// sample time
-	gain = 0.9 / peakA;	// target gain
-	if (gain > 1.0)
-		gain = 1.0;
-	if (gainB > gain) {
-		x = 1.0 - exp(- dtmp /  0.010);
-		gainB = gainB * (1 - x) + x * gain;	// gainB too high
-	}
-	else {
-		x  = 1.0 - exp(- dtmp / 10.000);
-		gainB = gainB * (1 - x) + x * gain;	// gainB too low
-	}
-//printf ("gain %10.6lf  gainB  %10.6lf  dtmp %10.6lf  x %10.6lf  count %d\n", gain, gainB, dtmp, x, count);
-	for (i = 0; i < count; i++) {
-		csample = filtered[i];
-		csample *= gainB;
-		amplitude = cabs(csample);
-		if (amplitude > 1.0)
-			csample /= amplitude;
-		filtered[i] = csample * CLIP16;		// convert back to 16 bits
-	}
-	if (mic_interp > 1)
-		count = quisk_cInterpolate(filtered, count, &filtInterp, mic_interp);
+		}
+		// round off peaks
+		CcmPeak(NULL, csamples, count);
 #if DEBUG_IO
-	for (i = 0; i < count; i++) {
-		amplitude = cabs(filtered[i]) / CLIP16;
-		if (amplitude > peakOut3)
-			peakOut3 = amplitude;
-	}
+		for (i = 0; i < count; i++) {
+			magn = cabs(csamples[i]);
+			if (magn > Level4)
+				Level4 = magn;
+		}
 #endif
-
-//printf("%5.2lf\n", increasing);
+		// remove clipping distortion
+		count = quisk_cDecimate(csamples, count, &cfiltAudio3, 1);
+		// Interpolate up to 48000
+		if (MIC_OUT_RATE != sample_rate)
+			count = quisk_cInterpolate(csamples, count, &cfiltInterp, MIC_OUT_RATE / sample_rate);
+		// convert back to 16 bits and reduce level to allow headroom
+		for (i = 0; i < count; i++) {
+			csamples[i] /= 1.3;
+			magn = cabs(csamples[i]);
+			if (magn > 1.0)
+				filtered[i] = csamples[i] / magn * CLIP16;
+			else
+				filtered[i] = csamples[i] * CLIP16;
+#if DEBUG_IO
+			if (magn > dbOut)
+				dbOut = magn;
+#endif
+		}
+	}
+	else {		// AM and FM
+#if DEBUG_IO
+		for (i = 0; i < count; i++) {
+			magn = fabs(dsamples[i]);
+			if (magn > Level3)
+				Level3 = magn;
+		}
+#endif
+		// round off peaks
+		CcmPeak(dsamples, NULL, count);
+#if DEBUG_IO
+		for (i = 0; i < count; i++) {
+			magn = fabs(dsamples[i]);
+			if (magn > Level4)
+				Level4 = magn;
+		}
+#endif
+		// remove clipping distortion
+		count = quisk_dFilter(dsamples, count, &dfiltAudio3);
+		// Interpolate up to 48000
+		if (MIC_OUT_RATE != sample_rate)
+			count = quisk_dInterpolate(dsamples, count, &dfiltInterp, MIC_OUT_RATE / sample_rate);
+		// convert back to 16 bits and reduce level to allow headroom
+		for (i = 0; i < count; i++) {
+			dsamples[i] /= 1.3;
+			magn = fabs(dsamples[i]);
+#if DEBUG_IO
+			if (magn > dbOut)
+				dbOut = magn;
+#endif
+			if (magn > 1.0)
+				filtered[i] = dsamples[i] / magn * CLIP16;
+			else
+				filtered[i] = dsamples[i] * CLIP16;
+		}
+	}
 #if DEBUG_IO
 	if (debug_timer == 0) {
-		printf ("peakIn %10.6lf  peakOut1 %10.6lf  peakOut2 %10.6lf  peakOut3 %10.6lf  gainA %6.1lf  gainB %6.3lf",
-			peakIn, peakOut1, peakOut2, peakOut3, gainA, gainB);
-		if (peakOut3 > 1.0)
-			printf ("  CLIP\n");
+		if (dbOut > 1.0)
+			clip = "Clip";
 		else
-			printf ("\n");
-		peakIn = peakOut1 = peakOut2 = peakOut3 = 0;
+			clip = "";
+		dbOut = 20 * log10(dbOut);
+		printf ("pre %3.1lf dB clip %2.0lf InMax %6.2lf   Level0 %6.2lf  Level1 %6.2lf  Level2 %6.2lf  Level3 %6.2lf  Level4 %6.2lf  dbOut %6.2lf  %s\n",
+			quisk_mic_preemphasis, 20 * log10(quisk_mic_clip), 20 * log10(inMax), 20 * log10(Level0),
+			20 * log10(Level1), 20 * log10(Level2), 20 * log10(Level3),  20 * log10(Level4), dbOut, clip);
+		Level0 = Level1 = Level2 = Level3 = Level4 = dbOut = 0;
 	}
-#endif
-#if DEBUG_IO
 	//QuiskPrintTime("    tx_filter", 2);
 #endif
 	return count;
@@ -363,8 +511,8 @@ static int tx_filter_digital(complex * filtered, int count, double volume)
 	static double peakIn = 0, peakOut2 = 0;		// input/output level
 #endif
 	if (!filtered) {		// initialization
-		quisk_filt_dInit(&filter1, quiskMicFilt48Coefs, sizeof(quiskMicFilt48Coefs)/sizeof(double));
-		quisk_filt_tune(&filter1, 1650.0 / 48000, rxMode != 2);
+		quisk_filt_dInit(&filter1, quiskMic5Filt48Coefs, sizeof(quiskMic5Filt48Coefs)/sizeof(double));
+		quisk_filt_tune(&filter1, 2650.0 / 48000, rxMode != 2);
 		return 0;
 	}
 #if DEBUG_IO
@@ -448,7 +596,7 @@ PyObject * quisk_get_tx_filter(PyObject * self, PyObject * args)
 		}
 	}
 	// now filter the signal using the transmit filter
-	tx_filter(NULL, 0, 0);								// initialize
+	tx_filter(NULL, 0);				// initialize
 	scale = 1.0;
 	for (i = 0; i < data_width; i++)
 		if (fabs(average[i + nTaps]) > scale)
@@ -456,10 +604,10 @@ PyObject * quisk_get_tx_filter(PyObject * self, PyObject * args)
 	scale = CLIP16 / scale;		// limit to CLIP16
 	for (i = 0; i < nTaps; i++)
 		samples[i] = average[i] * scale;
-	tx_filter(samples, nTaps, 1);			// process initial samples
+	tx_filter(samples, nTaps);			// process initial samples
 	for (i = 0; i < data_width; i++)
 		samples[i] = average[i + nTaps] * scale;
-	tx_filter(samples, data_width, 1);	// process the samples
+	tx_filter(samples, data_width);	// process the samples
 
 	for (i = 0; i < data_width; i++)	// multiply by window
 		samples[i] *= fft_window[i];
@@ -561,8 +709,9 @@ static void transmit_mic_imd(complex * cSamples, int count, double level)
 
 int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 {
-	int i, sample, maximum, interp;
+	int i, sample, maximum, interp, mic_interp;
 	double d;
+	static struct quisk_cFilter filtInterp={NULL};
 
 // Microphone sample are input at mic_sample_rate.  But after processing,
 // the output rate is MIC_OUT_RATE.
@@ -615,6 +764,14 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 		if (sample > maximum)
 			maximum = sample;
 	}
+    if (maximum > vox_level) {
+		is_vox = mic_sample_rate / 1000 * timeVOX;		// reset timer to maximum
+	}
+	else if(is_vox) {
+		is_vox -= count;		// decrement timer
+		if (is_vox < 0)
+			is_vox = 0;
+	}
 	if (maximum > mic_level)
 		mic_level = maximum;
 	mic_timer -= count;		// time out the max microphone level to display
@@ -636,7 +793,7 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 				transmit_udp(cSamples, count);
 			}
 			else if (spotLevel == 0) {
-				count = tx_filter(cSamples, count, 1);	// filter samples
+				count = tx_filter(cSamples, count);		// filter samples
 				transmit_udp(cSamples, count);
 			}
 			else {
@@ -646,14 +803,14 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 			break;
 		case 4:		// AM
 			if (quisk_record_state != PLAYBACK)		// no audio processing for recorded sound
-				count = tx_filter(cSamples, count, 0);
+				count = tx_filter(cSamples, count);
 			for (i = 0; i < count; i++)	// transmit (0.5 + ampl/2, 0)
 				cSamples[i] = (creal(cSamples[i]) + CLIP16) * 0.5;
 			transmit_udp(cSamples, count);
 			break;
 		case 5:		// FM
 			if (quisk_record_state != PLAYBACK)		// no audio processing for recorded sound
-				count = tx_filter(cSamples, count, 0);
+				count = tx_filter(cSamples, count);
 			for (i = 0; i < count; i++) {	// this is phase modulation == FM and 6 dB /octave preemphasis
 				cSamples[i] = CLIP16 * cexp(I * creal(cSamples[i]) / CLIP16 * modulation_index);
 			}
@@ -686,12 +843,65 @@ int quisk_process_microphone(int mic_sample_rate, complex * cSamples, int count)
 		}
 #endif
 	}
+	else if (quisk_record_state == RECORD_MIC) {
+		switch (rxMode) {
+		case 2:		// LSB
+		case 3:		// USB
+			count = tx_filter(cSamples, count);	// filter samples
+			break;
+		case 4:		// AM
+			count = tx_filter(cSamples, count);
+			break;
+		case 5:		// FM
+			count = tx_filter(cSamples, count);
+  			break;
+		default:
+			for (i = 0; i < count; i++)
+				cSamples[i] = 0;
+			break;
+		}
+		// Perhaps interpolate the mic samples back to the sound play rate
+		mic_interp = quisk_sound_state.playback_rate / MIC_OUT_RATE;
+		if (mic_interp > 1) {
+			if (! filtInterp.dCoefs)
+				quisk_filt_cInit(&filtInterp, quiskFilt12_19Coefs, sizeof(quiskFilt12_19Coefs)/sizeof(double));
+			count = quisk_cInterpolate(cSamples, count, &filtInterp, mic_interp);
+		}
+		quisk_tmp_record(cSamples, count, (double)CLIP32 / CLIP16);	// convert 16 to 32 bits
+	}
+	else if (DEBUG_MIC) {
+		count = tx_filter(cSamples, count);
+	}
+
 #if DEBUG_IO
 	//QuiskPrintTime("    process_mic", 1);
 #endif
 	return count;
 }
 
+PyObject * quisk_set_tx_audio(PyObject * self, PyObject * args, PyObject * keywds)
+{  /* Call with keyword arguments ONLY; change Tx audio parameters */
+	static char * kwlist[] = {"vox_level", "vox_time", "mic_clip", "mic_preemphasis", NULL} ;
+	int vlevel = -9999, clevel = -9999;
+
+	if (!PyArg_ParseTupleAndKeywords (args, keywds, "|iiid", kwlist,
+			&vlevel, &timeVOX, &clevel, &quisk_mic_preemphasis))
+		return NULL;
+	if (vlevel != -9999)
+		vox_level = (int)(pow(10.0, vlevel / 20.0) * CLIP16);	// Convert dB to 16-bit sample
+	if (clevel != -9999)
+		quisk_mic_clip = pow(10.0, clevel / 20.0);	// Convert dB to factor
+	Py_INCREF (Py_None);
+	return Py_None;
+}
+
+PyObject * quisk_is_vox(PyObject * self, PyObject * args)
+{	/* return the VOX state */
+	if (!PyArg_ParseTuple (args, ""))
+		return NULL;
+	return PyInt_FromLong(is_vox);
+}
+
 void quisk_close_mic(void)
 {
 	if (mic_socket != INVALID_SOCKET) {
@@ -723,8 +933,6 @@ void quisk_open_mic(void)
 #endif
 
 	modulation_index = QuiskGetConfigDouble("modulation_index", 1.6);
-	mic_max_gain = QuiskGetConfigDouble("mic_max_gain", 100.0);
-	mic_avg_gain = QuiskGetConfigDouble("mic_avg_gain", 10.0);
 	if (quisk_sound_state.tx_audio_port == 0x553B)
 		align4 = 0;		// Using old port: data starts at byte 42.
 	else
@@ -765,7 +973,7 @@ void quisk_open_mic(void)
 
 void quisk_set_tx_mode(void)	// called when the mode rxMode is changed
 {
-	tx_filter(NULL, 0, 0);
+	tx_filter(NULL, 0);
 	tx_filter_digital(NULL, 0, 0.0);
 #ifdef TEST_TX_WAV_FILE
 	if (!wavFp)			// convenient place to open file
