@@ -22,7 +22,9 @@
 
 #define DEBUG		0
 
-#define FM_FILTER_DEMPH		300.0		// Frequency of FM lowpass de-emphasis filter
+#define FM_FILTER_DEMPH		300.0				// Frequency of FM lowpass de-emphasis filter
+#define AGC_DELAY			15					// Delay in AGC buffer in milliseconds
+#define AGC_MAX_OUT			(CLIP32 * 0.7)		// Maximum AGC output level
 
 static int fft_error;			// fft error count
 static int count_fft;			// how many fft's have occurred (for average)
@@ -37,6 +39,18 @@ typedef struct fftd {
 	struct fftd * next;			// the next data block to use
 } fft_data;
 
+struct AgcState {		// Store state information for the AGC
+	int buf_size;
+	int index_read;
+	int index_start;
+	int is_clipping;
+	double themax;
+	double gain;
+	double delta;
+	double target_gain;
+	complex * c_samp;
+};
+
 static fft_data * FFT1, * FFT2, * FFT3;	// data for three fft's		WB4JFI ADD third FFT
 static fft_data * ptWriteFft;		// Write the current samples to this fft
 static double * fft_avg;		// Array to average the FFT
@@ -69,17 +83,17 @@ static int quisk_decim_srate;				// Sample rate after decimation
 static int quisk_demod_srate;				// Sample rate after demodulation
 static int quisk_filter_srate=48000;		// Frequency for filters
 static int split_rxtx;						// Are we in split rx/tx mode?
+static int kill_audio;				// Replace radio sound with silence
+static int quisk_transmit_mode;				// Are we in transmit mode for semi-break-in CW?
 
 static double sidetoneVolume;		// Audio output level of the CW sidetone, 0.0 to 1.0
 static int keyupDelay;			// Play silence after sidetone ends
 static complex sidetonePhase;		// Phase increment for sidetone
 int quisk_sidetoneCtrl;			// sidetone control value 0 to 1000
 
-static int agcInUse;			// 0 for no AGC
-static double agcRelease, agcLevel;	// AGC parameters
-static double agcMaxGain;		// Max AGC gain
-static double agcOffGain;		// Gain when AGC is off
-static double squelch_level;		// setting of squelch control
+static double agcReleaseGain=80;		// AGC maximum gain
+static double agcTimeRelease=0.01;		// Release time fraction (not seconds)
+static double squelch_level;			// setting of squelch control
 static int quisk_invert_spectrum = 0;	// Invert the input RF spectrum
 
 static double Smeter;			// Measured RMS signal strength
@@ -702,7 +716,8 @@ static PyObject * set_record_state(PyObject * self, PyObject * args)
 	if (!PyArg_ParseTuple (args, "i", &button))
 		return NULL;
 	switch (button) {
-	case 0:			// press record
+	case 0:			// press record radio
+	case 4:			// press record microphone
 		if ( ! quisk_record_buffer) {	// initialize
 			quisk_record_bufsize = (int)(QuiskGetConfigDouble("max_record_minutes", 0.25) * quisk_sound_state.playback_rate * 60.0 + 0.2);
 			quisk_record_buffer = (float *)malloc(sizeof(float) * quisk_record_bufsize);
@@ -711,7 +726,10 @@ static PyObject * set_record_state(PyObject * self, PyObject * args)
 		quisk_play_index = 0;
 		quisk_mic_index = 0;
 		quisk_record_full = 0;
-		quisk_record_state = RECORD;
+		if (button == 0)
+			quisk_record_state = RECORD_RADIO;
+		else
+			quisk_record_state = RECORD_MIC;
 		break;
 	case 1:			// release record
 		quisk_record_state = IDLE;
@@ -735,12 +753,12 @@ static PyObject * set_record_state(PyObject * self, PyObject * args)
 	return PyInt_FromLong(quisk_record_state != PLAYBACK);
 }
 
-static void tmp_record(complex * cSamples, int nSamples)		// save radio sound
+void quisk_tmp_record(complex * cSamples, int nSamples, double scale)		// save sound
 {
 	int i;
 
 	for (i = 0; i < nSamples; i++) {
-		quisk_record_buffer[quisk_record_index++] = creal(cSamples[i]);
+		quisk_record_buffer[quisk_record_index++] = creal(cSamples[i]) * scale;
 		if (quisk_record_index >= quisk_record_bufsize) {
 			quisk_record_index = 0;
 			quisk_record_full = 1;
@@ -1082,64 +1100,128 @@ static int quisk_process_demodulate(complex * cSamples, double * dsamples, int n
 	return nSamples;
 }
 
-static double quisk_process_agc(double agcPeak, double agcGain, int nSamples)
-{  // return the new agcGain given agcPeak
-	double d, di;
+static void process_agc(struct AgcState * dat, complex * csamples, int count, int is_cpx)
+{
+	int i;
+	double out_magn, buf_magn, dtmp, clip_gain;
+	complex csample;
 #if DEBUG
-	static int printit;
-	static time_t time0;
-
-	if (time(NULL) != time0) {
-		time0 = time(NULL);
-		printit = 1;
-	}
-	else {
-		printit = 0;
-	}
+	static int printit=0;
+	static double maxout=1;
+	char * clip;
 #endif
 
-	// Normalize peak amplitude to 1.0 maximum
-	if (agcPeak < 2E3)
-		agcPeak = 2E3 / CLIP32;
-	else
-		agcPeak /= CLIP32;
-	// Change volume using automatic gain control, AGC.
-	// The maximum signal is about 2^31, namely 2e9.
-	// This is the change fraction di, maximum 1
-	di = (double)nSamples / quisk_sound_state.playback_rate / agcRelease;
-	if (di > 1.0)
-		di = 1.0;
-	// The current output if agcGain is not changed is agcPeak * agcGain
-	if (rxMode == 5) {		// mode is FM
-		// Brick wall agc; make all signals the same volume
-		if (agcPeak * agcGain >= 1.0)	// clipping
-			agcGain = 0.5 / agcPeak;
-		else	// move toward target volume
-			agcGain += (0.5 / agcPeak - agcGain) * di;
+	if ( ! dat->buf_size) {		// initialize
+		dat->buf_size = quisk_sound_state.playback_rate * AGC_DELAY / 1000;	// total delay in samples
+		//printf("play rate %d  buf_size %d\n", quisk_sound_state.playback_rate, dat->buf_size);
+		dat->index_read = 0;				// Index to output; and then write a new sample here
+		dat->index_start = 0;				// Start index for measure of maximum sample
+		dat->is_clipping = 0;				// Are we decreasing gain to handle a clipping condition?
+		dat->themax = 1.0;					// Maximum sample in the buffer
+		dat->gain = 100;					// Current output gain
+		dat->delta = 0;						// Amount to change dat->gain at each sample
+		dat->target_gain = 100;				// Move to this gain unless we clip
+		dat->c_samp = (complex *) malloc(dat->buf_size * sizeof(complex));		// buffer for complex samples
+		for (i = 0; i < dat->buf_size; i++)
+			dat->c_samp[i] = 0;
+		return;
 	}
-	else if (agcInUse) {
-		// Set gain with the level control, but limit max signal
-		d = agcMaxGain * agcLevel;	// target gain
-		if (d > 0.5 / agcPeak)
-			d = 0.5 / agcPeak;
-		if (agcPeak * agcGain >= 1.0)	// clipping
-			agcGain = 0.5 / agcPeak;
+	for (i = 0; i < count; i++) {
+		csample = csamples[i];
+		csamples[i] = dat->c_samp[dat->index_read] * dat->gain;		// FIFO output
+		if (is_cpx)
+			out_magn = cabs(csamples[i]);
 		else
-			agcGain += (d - agcGain) * di;
-	}
-	else {	// For no AGC set the gain, but limit to clipping
-		agcGain += (agcOffGain - agcGain) * di;
-		if (agcPeak * agcGain >= 1.0)	// clipping
-			agcGain = 1.0 / agcPeak;
-	}
+			out_magn = fabs(creal(csamples[i]));
+		//if(dat->is_clipping == 1)
+			//printf("      index %5d  out_magn %.5lf  gain %.2lf  delta  %.5lf\n",dat->index_read, out_magn / CLIP32, dat->gain, dat->delta);
 #if DEBUG
-	if (printit) {
-		d = CLIP32;
-		printf("agcGain %12.1lf  agcMaxGain * agcLevel %.1lf  agcPeak %.6lf agcOffGain %.1lf\n",
-			agcGain, agcMaxGain * agcLevel, agcPeak / 2.e9, agcOffGain);
-	}
+		if (out_magn > maxout)
+			maxout = out_magn;
 #endif
-	return agcGain;
+		if (out_magn > CLIP32)	{
+			csamples[i] /= out_magn;
+#if DEBUG
+			printf("Clip out_magn %8.5lf  is_clipping %d  index_read %5d  index_start %5d  gain %8.5lf\n",
+				out_magn / CLIP32, dat->is_clipping, dat->index_read, dat->index_start, dat->gain);
+#endif
+		}
+		dat->c_samp[dat->index_read] = csample;		// write new sample at read index
+		if (is_cpx)
+			buf_magn = cabs(csample);
+		else
+			buf_magn = fabs(creal(csample));
+		if (dat->is_clipping == 0) {
+			if (buf_magn * dat->gain > AGC_MAX_OUT) {
+				dat->target_gain = AGC_MAX_OUT / buf_magn;
+				dat->delta = (dat->gain - dat->target_gain) / dat->buf_size;
+				dat->is_clipping = 1;
+				dat->themax = buf_magn;
+				// printf("Start index %5d  buf_magn %10.8lf  target %8.2lf  gain %8.2lf  delta  %8.5lf\n",
+				// 	dat->index_read, buf_magn / CLIP32, dat->target_gain, dat->gain, dat->delta);
+				dat->gain -= dat->delta;
+			}
+			else if (dat->index_read == dat->index_start) {
+				clip_gain = AGC_MAX_OUT / dat->themax;		// clip gain based on the maximum sample in the buffer
+				if (rxMode == 5)		// mode is FM
+					dat->target_gain = clip_gain;
+				else if (agcReleaseGain > clip_gain)
+					dat->target_gain = clip_gain;
+				else
+					dat->target_gain = agcReleaseGain;
+				dat->themax = buf_magn;
+				dat->gain = dat->gain * (1.0 - agcTimeRelease) + dat->target_gain * agcTimeRelease;
+				// printf("New   index %5d  themax %7.5lf  clip_gain %5.0lf  agcReleaseGain %5.0lf\n",
+				// 	dat->index_start, dat->themax / CLIP32, clip_gain, agcReleaseGain);
+			}
+			else {
+				if (dat->themax < buf_magn)
+					dat->themax = buf_magn;
+				dat->gain = dat->gain * (1.0 - agcTimeRelease) + dat->target_gain * agcTimeRelease;
+			}
+		}
+		else {		// dat->is_clipping == 1;  we are handling a clip condition
+			if (buf_magn > dat->themax) {
+				dat->themax = buf_magn;
+				dat->target_gain = AGC_MAX_OUT / buf_magn;
+				dtmp = (dat->gain - dat->target_gain) / dat->buf_size;	// new value of delta
+				if (dtmp > dat->delta) {
+					dat->delta = dtmp;
+					// printf(" Strt index %5d  buf_magn %10.8lf  target %8.2lf  gain %8.2lf  delta  %8.5lf\n",
+					// 	dat->index_read, buf_magn / CLIP32, dat->target_gain, dat->gain, dat->delta);
+				}
+				else {
+					// printf(" Plus index %5d  buf_magn %10.8lf  target %8.2lf  gain %8.2lf  delta  %8.5lf\n",
+					// 	dat->index_read, buf_magn / CLIP32, dat->target_gain, dat->gain, dat->delta);
+				}
+			}
+			dat->gain -= dat->delta;
+			if (dat->gain <= dat->target_gain) {
+				dat->is_clipping = 0;
+				dat->gain = dat->target_gain;
+				// printf("End   index %5d  buf_magn %10.8lf  target %8.2lf  gain %8.2lf  delta  %8.5lf  themax %10.8lf\n",
+				// 	dat->index_read, buf_magn / CLIP32, dat->target_gain, dat->gain, dat->delta, dat->themax / CLIP32);
+				dat->themax = buf_magn;
+				dat->index_start = dat->index_read;
+			}
+		}
+		if (++dat->index_read >= dat->buf_size)
+			dat->index_read = 0;
+#if DEBUG
+		if (printit++ >= quisk_sound_state.playback_rate * 500 / 1000) {
+			printit = 0;
+			dtmp = 20 * log10(maxout / CLIP32);
+			if (dtmp >= 0)
+				clip = "Clip";
+			else
+				clip = "";
+			printf("Out agcGain %5.0lf   target_gain %9.0lf   gain %9.0lf  output %7.2lf %s\n",
+				agcReleaseGain, dat->target_gain, dat->gain, dtmp, clip);
+			maxout = 1;
+		}
+#endif
+	}
+	return;
 }
 
 int quisk_process_samples(complex * cSamples, int nSamples)
@@ -1147,7 +1229,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 // Called when samples are available.
 // Samples range from about 2^16 to a max of 2^31.
 	int i, n, nout, is_key_down, interp;
-	double d, dr, di, agcPeak;
+	double d, di;
 	double double_filter_decim;
 	complex phase;
 	int orig_nSamples;
@@ -1156,8 +1238,6 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	static double * dsamples = NULL;
 	static double * dsamples2 = NULL;
 	static complex * orig_cSamples = NULL;
-	static double agcGainReal;			// Volume level control for audio output
-	static double agcGainImag;			// Volume level control for audio output
 	static complex rxTuneVector = 1;
 	static complex txTuneVector = 1;
 	static complex sidetoneVector = BIG_VOLUME;
@@ -1170,6 +1250,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	static struct quisk_cHB45Filter HalfBand7 = {NULL, 0, 0};
 	static struct quisk_cHB45Filter HalfBand8 = {NULL, 0, 0};
 	static struct quisk_cHB45Filter HalfBand9 = {NULL, 0, 0};
+	static struct AgcState Agc1 = {0}, Agc2 = {0};
 
 #if DEBUG
 	static int printit;
@@ -1198,7 +1279,7 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 		dsamples2 = (double *)malloc(size_dsamples * sizeof(double));
 		orig_cSamples = (complex *)malloc(size_dsamples * sizeof(complex));
 	}
-	is_key_down = quisk_is_key_down();
+	is_key_down = quisk_transmit_mode || quisk_is_key_down();
 	orig_nSamples = nSamples;
 	if (split_rxtx)
 		memcpy(orig_cSamples, cSamples, nSamples * sizeof(complex));
@@ -1441,53 +1522,20 @@ int quisk_process_samples(complex * cSamples, int nSamples)
 	// Find the peak signal amplitude
 start_agc:
 	if (rxMode == 6 || rxMode == 9) {		// DGT-IQ stereo sound
-		agcPeak = 0;
-		for (i = 0; i < nSamples; i++) {
-			d = creal(cSamples[i]);
-			d = fabs(d);
-			if (agcPeak < d)
-				agcPeak = d;
-			d = cimag(cSamples[i]);
-			d = fabs(d);
-			if (agcPeak < d)
-				agcPeak = d;
-		}
-		agcGainReal = quisk_process_agc(agcPeak, agcGainReal, nSamples);
-		d = agcGainReal * 0.95;
-		for (i = 0; i < nSamples; i++)
-			cSamples[i] *= d;
+		process_agc(&Agc1, cSamples, nSamples, 1);
 	}
-	else if (split_rxtx) {		// sepatate AGC for left and right channels
-		dr = di = 0;
+	else if (split_rxtx) {		// separate AGC for left and right channels
 		for (i = 0; i < nSamples; i++) {
-			d = creal(cSamples[i]);
-			d = fabs(d);
-			if (dr < d)
-				dr = d;
-			d = cimag(cSamples[i]);
-			d = fabs(d);
-			if (di < d)
-				di = d;
+			orig_cSamples[i] = cimag(cSamples[i]);
+			cSamples[i] = creal(cSamples[i]);
 		}
-		agcGainReal = quisk_process_agc(dr, agcGainReal, nSamples);
-		agcGainImag = quisk_process_agc(di, agcGainImag, nSamples);
-		dr = agcGainReal * 0.95;
-		di = agcGainImag * 0.95;
+		process_agc(&Agc1, cSamples, nSamples, 0);
+		process_agc(&Agc2, orig_cSamples, nSamples, 0);
 		for (i = 0; i < nSamples; i++)
-			cSamples[i] = creal(cSamples[i]) * dr + I * cimag(cSamples[i]) * di;
+			cSamples[i] = creal(cSamples[i]) + I * creal(orig_cSamples[i]);
 	}
 	else {					// monophonic sound
-		agcPeak = 0;
-		for (i = 0; i < nSamples; i++) {
-			d = creal(cSamples[i]);
-			d = fabs(d);
-			if (agcPeak < d)
-				agcPeak = d;
-		}
-		agcGainReal = quisk_process_agc(agcPeak, agcGainReal, nSamples);
-		d = agcGainReal * 0.95;
-		for (i = 0; i < nSamples; i++)
-			cSamples[i] *= d;
+		process_agc(&Agc1, cSamples, nSamples, 0);
 	}
 #if DEBUG
 	if (printit) {
@@ -1498,19 +1546,22 @@ start_agc:
 	}
 #endif
 
-	if (rxMode == 5) {		// mode is FM
-		if (IsSquelch(quisk_tx_tune_freq)) {
+	if (kill_audio) {
+		is_squelch = 1;
+	}
+	else if (rxMode == 5) {		// mode is FM
+		if (IsSquelch(quisk_tx_tune_freq))
 			is_squelch = 1;
-			for (i = 0; i < nSamples; i++)
-				cSamples[i] = 0;
-		}
-		else {
+		else
 			is_squelch = 0;
-		}
 	}
 	else {
 		is_squelch = 0;
 	}
+	if (is_squelch) {
+		for (i = 0; i < nSamples; i++)
+			cSamples[i] = 0;
+	}
 	if (keyupEnvelope < 1.0) {		// raise volume slowly after the key goes up
 		di = 1. / (quisk_sound_state.playback_rate * 5e-3);		// 5 milliseconds
 		for (i = 0; i < nSamples; i++) {
@@ -1522,10 +1573,10 @@ start_agc:
 			cSamples[i] *= keyupEnvelope;
 		}
 	}
-	if (quisk_record_state == RECORD && ! is_squelch)
-		tmp_record(cSamples, nSamples);		// save radio sound
+	if (quisk_record_state == RECORD_RADIO && ! is_squelch)
+		quisk_tmp_record(cSamples, nSamples, 1.0);		// save radio sound
 	if (quisk_record_state == PLAYBACK)
-		tmp_playback(cSamples, nSamples, quisk_audioVolume);	// replace radio sound
+		tmp_playback(cSamples, nSamples, 1.0);	// replace radio sound
 	return nSamples;
 }
 
@@ -1894,6 +1945,7 @@ int quisk_read_rx_udp(complex * samp)	// Read samples from UDP
 static PyObject * open_sound(PyObject * self, PyObject * args)
 {
 	char * capt, * play, * mname, * mip, * mpname;
+    double dtmp;
 
 	if (!PyArg_ParseTuple (args, "ssiiissiiiidsi", &capt, &play,
 				&quisk_sound_state.sample_rate,
@@ -1925,6 +1977,8 @@ static PyObject * open_sound(PyObject * self, PyObject * args)
 	quisk_open_sound();
 	quisk_open_mic();
 	sample_rate = quisk_sound_state.sample_rate;
+	dtmp = QuiskGetConfigDouble("agc_release_time", 1.0);
+	agcTimeRelease = 1.0 - exp( - 1.0 / quisk_sound_state.playback_rate / dtmp);	// long time constant for AGC release
 	return get_state(NULL, NULL);
 }
 
@@ -1975,10 +2029,10 @@ static PyObject * mixer_set(PyObject * self, PyObject * args)
 {
 	char * card_name;
 	int numid;
-	double value;
+	PyObject * value;
 	char err_msg[QUISK_SC_SIZE];
 
-	if (!PyArg_ParseTuple (args, "sid", &card_name, &numid, &value))
+	if (!PyArg_ParseTuple (args, "siO", &card_name, &numid, &value))
 		return NULL;
 
 	quisk_mixer_set(card_name, numid, value, err_msg, QUISK_SC_SIZE);
@@ -1994,8 +2048,8 @@ static PyObject * invert_spectrum(PyObject * self, PyObject * args)
 }
 
 static PyObject * set_agc(PyObject * self, PyObject * args)
-{  /* Change the AGC parameters */
-	if (!PyArg_ParseTuple (args, "idd", &agcInUse, &agcLevel, &agcRelease))
+{  /* Change the AGC level */
+	if (!PyArg_ParseTuple (args, "d", &agcReleaseGain))
 		return NULL;
 	Py_INCREF (Py_None);
 	return Py_None;
@@ -2109,6 +2163,22 @@ static PyObject * set_squelch(PyObject * self, PyObject * args)
 	return Py_None;
 }
 
+static PyObject * set_kill_audio(PyObject * self, PyObject * args)
+{	/* replace radio sound with silence */
+	if (!PyArg_ParseTuple (args, "i", &kill_audio))
+		return NULL;
+	Py_INCREF (Py_None);
+	return Py_None;
+}
+
+static PyObject * set_transmit_mode(PyObject * self, PyObject * args)
+{	/* Set the radio to transmit mode */
+	if (!PyArg_ParseTuple (args, "i", &quisk_transmit_mode))
+		return NULL;
+	Py_INCREF (Py_None);
+	return Py_None;
+}
+
 static PyObject * set_volume(PyObject * self, PyObject * args)
 {
 	if (!PyArg_ParseTuple (args, "d", &quisk_audioVolume))
@@ -2560,8 +2630,6 @@ static PyObject * record_app(PyObject * self, PyObject * args)
 	Py_INCREF(quisk_pyConfig);
 
 	rx_udp_clock = QuiskGetConfigDouble("rx_udp_clock", 122.88e6);
-	agcMaxGain = QuiskGetConfigDouble("agc_max_gain", 15000.0);
-	agcOffGain = QuiskGetConfigDouble("agc_off_gain", 1400.0);
 	quisk_sound_state.sample_rate = sample_rate;	// also set by open_sound()
 	is_little_endian = 1;	// Test machine byte order
 	if (*(char *)&is_little_endian == 1)
@@ -2699,12 +2767,16 @@ static PyMethodDef QuiskMethods[] = {
 	{"set_file_record", quisk_set_file_record, METH_VARARGS, "Set the state and names of the recording files."},
 	{"set_filters", set_filters, METH_VARARGS, "Set the receive audio I and Q channel filters."},
 	{"set_auto_notch", set_auto_notch, METH_VARARGS, "Set the auto notch on or off."},
+	{"set_kill_audio", set_kill_audio, METH_VARARGS, "Replace radio sound with silence."},
 	{"set_noise_blanker", set_noise_blanker, METH_VARARGS, "Set the noise blanker level."},
 	{"set_record_state", set_record_state, METH_VARARGS, "Set the temp buffer record and playback state."},
 	{"set_rx_mode", set_rx_mode, METH_VARARGS, "Set the receive mode: CWL, USB, AM, etc."},
 	{"set_spot_level", quisk_set_spot_level, METH_VARARGS, "Set the spot mode: 0, 1, ... or -1 for no spot"},
 	{"set_sidetone", set_sidetone, METH_VARARGS, "Set the sidetone volume and frequency."},
+	{"set_transmit_mode", set_transmit_mode, METH_VARARGS, "Change the radio to transmit mode independent of key_down."},
 	{"set_volume", set_volume, METH_VARARGS, "Set the audio output volume."},
+	{"set_tx_audio", (PyCFunction)quisk_set_tx_audio, METH_VARARGS|METH_KEYWORDS, "Set the transmit audio parameters."},
+	{"is_vox", quisk_is_vox, METH_VARARGS, "return the VOX state zero or one."},
 	{"set_split_rxtx", set_split_rxtx, METH_VARARGS, "Set split for rx/tx."},
 	{"set_tune", set_tune, METH_VARARGS, "Set the tuning frequency."},
 	{"test_1", test_1, METH_VARARGS, "Test 1 function."},
