@@ -1,5 +1,6 @@
 
 #define DEBUG_IO	0
+#define DEBUG_MIC	0
 
 // Sound parameters
 //
@@ -94,7 +95,8 @@ struct sound_conf {
 
 enum quisk_rec_state {
 	IDLE,
-	RECORD,
+	RECORD_RADIO,
+	RECORD_MIC,
 	PLAYBACK } ;
 extern enum quisk_rec_state quisk_record_state;
 
@@ -122,6 +124,8 @@ extern PyObject * quisk_micplay_channels(PyObject * , PyObject *);
 extern PyObject * quisk_sound_devices(PyObject * , PyObject *);
 extern PyObject * quisk_sound_errors(PyObject *, PyObject *);
 extern PyObject * quisk_set_file_record(PyObject *, PyObject *);
+extern PyObject * quisk_set_tx_audio(PyObject *, PyObject *, PyObject *);
+extern PyObject * quisk_is_vox(PyObject *, PyObject *);
 
 // These function pointers are the Start/Stop/Read interface for
 // the SDR-IQ and any other C-language extension modules that return
@@ -137,7 +141,7 @@ void quisk_play_samples(double *, int);
 void quisk_play_zeros(int);
 void quisk_start_sound(void);
 int quisk_get_overrange(void);
-void quisk_mixer_set(char *, int, double, char *, int);
+void quisk_mixer_set(char *, int, PyObject *, char *, int);
 int quisk_read_sound(void);
 int quisk_process_microphone(int, complex *, int);
 void quisk_open_mic(void);
@@ -151,6 +155,7 @@ void quisk_set_tx_mode(void);
 void ptimer(int);
 int quisk_extern_demod(complex *, int, double);
 void quisk_tmp_microphone(complex *, int);
+void quisk_tmp_record(complex * , int, double);
 
 int  quisk_read_alsa(struct sound_dev *, complex *);
 void quisk_play_alsa(struct sound_dev *, int, complex *, int, double);
