@@ -3,6 +3,11 @@
 # .quisk_conf.py and make changes there.  For a normal sound card
 # configuration, copy quisk_conf_model.py to your .quisk_conf.py.
 #
+# PLEASE DO **NOT** COPY THIS FILE AND USE IT AS A START FOR YOUR CONFIGURATION FILE!
+# YOUR CONFIGURATION FILE SHOULD ONLY HAVE LINES THAT DIFFER FROM THIS FILE.  QUISK
+# IMPORTS THIS FILE FIRST, AND THEN YOUR CONFIG FILE OVERWRITES A FEW ITEMS SUCH AS
+# SOUND CARD NAMES.
+#
 # Quisk imports quisk_conf_defaults to set its configuration.
 # If you have a configuration file, it then overwrites the defaults
 # with your parameters.  Your configuration file must be named
@@ -21,6 +26,7 @@
 # quisk_hardware_model.py is used instead.
 
 import sys
+import wx
 
 # Import the default Hardware module.  You can import a different module in
 # your .quisk_conf.py.
@@ -71,12 +77,12 @@ waterfall_graph_size = 80
 # The sliders go from zero to 160.
 graph_y_scale = 100
 graph_y_zero  = 0
-waterfall_y_scale = 80
-waterfall_y_zero  = 40
+waterfall_y_scale = 80		# Initial value; new values are saved for each band
+waterfall_y_zero  = 40		# Initial value; new values are saved for each band
 waterfall_graph_y_scale = 100
 waterfall_graph_y_zero = 60
 scope_y_scale = 80
-scope_y_zero  = 0		# Currently doesn't do anything
+scope_y_zero  = 0			# Currently doesn't do anything
 filter_y_scale = 90
 filter_y_zero  = 0
 
@@ -161,14 +167,17 @@ display_fraction = 1.00
 
 # Quisk has record and playback buttons to save radio sound.  If there is no more room for
 # sound, the old sound is discarded and the most recent sound is retained.  This controls
-# the maximum length of sound storage in minutes.  If you want to transmit recorded sound,
-# then mic_sample_rate must equal playback_rate and both must be 48000.
-max_record_minutes = 0.25
+# the maximum time of sound storage in minutes for this recorded audio, and also the record
+# time for the Tx Audio test screen.
+#
+# If you want to transmit recorded sound, then mic_sample_rate must equal playback_rate and both must be 48000.
+max_record_minutes = 1.00
 
 # Thanks to Steve Murphy, KB8RWQ for the patch adding additional color control.
 # Thanks to Christof, DJ4CM for the patch adding additional color control. 
 # Define colors used by all widgets in wxPython colour format:
 color_bg			= 'light steel blue'	# Lower screen background
+color_bg_txt		= 'black'             	# Lower screen text color
 color_graph			= 'lemonchiffon1'		# Graph background
 color_config2		= 'lemonchiffon3'		# color in tab row of config screen
 color_gl			= 'grey'				# Lines on the graph
@@ -190,10 +199,11 @@ color_bandwidth		= 'lemonchiffon2'		# color for bandwidth display; thanks to WB4
 #color_bandwidth = 'lemonchiffon3'
 color_txline		= 'red'					# vertical line color for tx in graph
 color_rxline		= 'green'				# vertical line color for rx in graph
-color_notebook_txt  = 'black'               # text of notebook lables
+color_notebook_txt  = 'black'               # text of notebook labels
 
 # This is a dark color scheme designed by Steve Murphy, KB8RWQ.
 #color_bg                = '#111111'
+#color_bg_txt            = 'white'
 #color_graph             = '#111111'
 #color_config2           = color_bg
 #color_gl                = '#555555'
@@ -208,13 +218,13 @@ color_notebook_txt  = 'black'               # text of notebook lables
 #color_freq              = '#333333'
 #color_freq_txt          = 'white'
 #color_entry             = color_freq
-#color_entry_txt         = color_freq_txt        # text color of entry box
+#color_entry_txt         = color_freq_txt
 #color_enable            = 'white'
 #color_disable           = 'black'
 #color_bandwidth         = '#333333'
 #color_txline            = 'red'
 #color_rxline            = 'green'
-#color_notebook_txt      = 'white'               # text of notebook lables
+#color_notebook_txt      = 'white'
 
 filter_display = 1	# Display the filter bandwidth on the graph screen; 0 or 1; thanks to WB4JFI
 
@@ -333,6 +343,12 @@ rx_udp_port = 0xBC77					# Sample source UDP port
 rx_udp_clock = 122880000				# ADC sample rate in Hertz
 sndp_active = True						# Enable setting the hardware IP to rx_udp_ip
 
+# Vendor and product ID's for the SoftRock
+usb_vendor_id = 0x16c0
+usb_product_id = 0x05dc
+# I2C-address of the SI570 in the softrock;  Thanks to Joachim Schneider, DB6QS
+si570_i2c_address = 0x55
+#si570_i2c_address = 0x70
 # Thanks to Ethan Blanton, KB8OJH, for this patch for the Si570 (many SoftRock's):
 # If you are using a DG8SAQ interface to set a Si570 clock directly, set
 # this to True.  Complex controllers which have their own internal
@@ -353,9 +369,14 @@ si570_xtal_freq = 114285000
 # If you use quisk_hardware_fixed.py, this is the fixed VFO frequency in Hertz
 fixed_vfo_freq = 7056000
 
-# Some hardware must be polled to get the key up/down state.  This is the time
-# between polls in milliseconds.  Use zero to turn off the poll.
+# Softrock hardware must be polled to get the key up/down state when using CW mode.
+# This is the time between polls in milliseconds.  Use zero to turn off the poll if you
+# only use SSB, or if your SoftRock does not have a key jack and USB control.
 key_poll_msec = 0
+#key_poll_msec = 5
+# Softrock transmit hardware uses semi break-in for CW operation.  This is the time in
+# seconds before changing back to receive.
+key_hang_time = 0.7
 
 # This determines what happens when you tune by dragging the mouse.  The correct
 # choice depends on how your hardware performs tuning.  You may want to use a
@@ -388,6 +409,12 @@ digital_output_name = ""	# device name for received audio
 # digital_output_name = digital_input_name
 digital_output_level = 0.7		# This is the volume control 0.0 to 1.0 for digital playback to fldigi, etc.
 
+# This option sends the raw I/Q samples to another program using a loopback device (Linux) or
+# a Virtual Audio Cable (Windows).  The sample rate is the same as the hardware sample rate.
+# Read the samples from the loopback device with another program.
+sample_playback_name = ""
+#sample_playback_name = "hw:Loopback,0"
+
 # You can control Quisk from Hamlib.  Set the Hamlib rig to 2 and the device for rig 2 to
 # localhost:4575, or other hamlib_port as used by Quisk.
 hamlib_port = 4575		# Standard port for Quisk control.  Set the port in Hamlib to 4575 too.
@@ -401,10 +428,16 @@ hamlib_port = 4575		# Standard port for Quisk control.  Set the port in Hamlib t
 # should be 48000 to enable digital modes and the sound recorder to work, but 8000 can be used.
 # Mic samples can be sent to an Ethernet device (use tx_ip and name_of_mic_play = "")
 # or to a sound card (use name_of_mic_play="hw:1" or other device).
+#
 # If mic samples are sent to a sound card for Tx, the samples are tuned to the audio
-# transmit frequency, and are set to zero unless the key is down.
-# If there is no mic (microphone_name = ""), it is still possible to transmit CW,
-# and you should set mic_playback_rate to the I/Q receive capture rate.
+# transmit frequency, and are set to zero unless the key is down.  You must set both
+# microphone_name and name_of_mic_play even for CW.  For softrock hardware, you usually
+# capture radio samples and play Tx audio on one soundcard; and capture the mic and play radio
+# sound on the other sound card at 48000 sps.  For example:
+#   name_of_sound_capt = "hw:0"				# high quality sound card at 48, 96, or 192 ksps
+#   name_of_sound_play = "hw:1"				# lower quality sound card at 48 ksps
+#   microphone_name    = name_of_sound_play
+#   name_of_mic_play   = name_of_sound_capt
 
 # Microphone capture:
 microphone_name = ""		# Name of microphone capture device (or "hw:1")
@@ -420,25 +453,20 @@ mic_out_volume = 0.7		# Microphone output volume (after all processing) as a fra
 # Microphone samples sent to UDP:
 tx_ip = ""				# Transmit IP address for mic sent to UDP (or "192.168.2.195")
 tx_audio_port = 0			# UDP port for mic samples (or 0x553B)
-# Microphone audio processing:
-# The original audio processing used mic_clip = 4.0; mic_preemphasis = -1.0
-# For no mic audio processing, use mic_clip = 1.0; mic_preemphasis = 0.0
-mic_clip = 3.0				# Mic amplitude clipping; larger numbers give more clipping
-mic_preemphasis = 0.6		# Mic pre-emphasis 0.0 (none) to 1.0; or -1.0 for a Butterworth filter
-# These parameters control the microphone gain adjustment.
-mic_avg_gain = 10.0			# Typical gain for the microphone in use
-mic_max_gain = 100.0		# Do not increase gain over this value
-
+# These microphone parameters are obsolete, and have no effect.  Use the Config/Tx Audio screen instead.
+#    mic_clip, mic_preemphasis, mic_avg_gain, mic_max_gain
 
 # If your mixing scheme inverts the RF spectrum, set this option to un-invert it
 invertSpectrum = 0
 
+# This is a list of mixer settings.  It only works for Linux; it has no effect in Windows.
 # Use "amixer -c 1 contents" to get a list of mixer controls and their numid's for
 # card 1 (or "-c 0" for card 0).  Then make a list of (device_name, numid, value)
-# for each control you need to set.  The sample settings are for my USB microphone.
+# for each control you need to set.  For a decimal fraction, use a Python float; for example,
+# use "1.0", not the integer "1".
 #mixer_settings = [
 #  ("hw:1", 2, 0.80),	# numid of microphone volume control, volume 0.0 to 1.0;
-#  ("hw:1", 1, 1.0)		# numid of capture on/off control, turn on with 1.0;
+#  ("hw:1", 1, 1)		# numid of capture on/off control, turn on with 1;
 #  ]
 
 # If you want Quisk to add a button to generate a 2-tone IMD test signal,
@@ -757,6 +785,26 @@ key_method = ""					# No keying, or internal method
 # key_method = "/dev/ttyS0"	# Use the named serial port
 # key_method = "192.168.1.44"	# Use UDP from this address
 
+# If your hardware file defines the method OnButtonPTT(self, event), then Quisk will
+# display a PTT button you can press.  The method must switch your hardware to
+# transmit somehow, for example, by setting a serial port pin to high.
+#
+# You can define two hot keys that when pressed simultaneously, will push the PTT button.
+# If you want only one hot key, set hot_key_ptt2 to None.  Use any of the wx.WXK_* key codes,
+# or the ord() of the letter.  Do not choose hot keys that interfere with other features
+# on your system; for example, system menus or the frequency entry box.
+hot_key_ptt1 = None
+hot_key_ptt2 = None
+# hot_key_ptt1 = wx.WXK_CONTROL
+# hot_key_ptt1 = wx.WXK_SHIFT
+# hot_key_ptt1 = wx.WXK_ALT
+# hot_key_ptt1 = wx.WXK_F5
+# hot_key_ptt2 = ord(' ')
+# hot_key_ptt2 = ord('A')
+
+# If you want Quisk to generate a sidetone, include self.use_sidetone = 1
+# in the __init__ method of your hardware file.
+#
 # If you are using keying, key-down throws away the current capture buffer
 # and starts a sidetone with a rise time of 5 milliseconds.  For
 # key-up, the sidetone is ended with a fall time of 5 milliseconds, then
@@ -768,16 +816,27 @@ key_method = ""					# No keying, or internal method
 
 keyupDelay = 23					# extra milliseconds silence on key up
 
-# This is a tuning parameter for the AGC.  It controls the maximum AGC gain and thus
-# the scale of the AGC slider control.  It depends on your sample magnitudes.
-agc_max_gain = 15000.0
-
-# This controls the audio gain when AGC is off.  It depends on your sample magnitudes.
-# Reduce it if turning off the AGC makes the sound too loud.
-agc_off_gain = 1400.0
-
-# This is the AGC release time.  It must be greater than zero.
-agc_release_time = 0.3
-
 # For FM transmit, this is the modulation index.
 modulation_index = 1.67
+
+# These are the tuning parameters for the AGC.  There is a button to turn AGC on or off,
+# but AGC still limits the peak amplitude to avoid clipping even if it is off.
+# Right click the AGC button to show the adjustment slider.  If the slider is at maximum,
+# all signals will have the same (maximum) amplitude.  For lower values, weak signals
+# will be somewhat less loud than strong signals; that is, some variation in signal
+# amplitude remains.
+
+# The AGC parameters are not used for FM, and the AGC button becomes a squelch button
+# with a squelch slider control.
+
+# This controls the maximum AGC gain and thus the scale of the AGC slider control.  If
+# it is too high, all signals reach the same amplitude at much less than 100% slider.
+# If it is too low, then all signals fail to have the same amplitude even at 100%.  But
+# the value is not critical, because you can adjust the slider a bit more.
+agc_max_gain = 15000.0
+
+# agc_off_gain is obsolete and has no effect.  Turn off AGC and adjust the slider instead.
+
+# This is the AGC release time in seconds.  It must be greater than zero.  It is the time
+# constant for gain recovery after a strong signal disappears.
+agc_release_time = 1.0
