@@ -15,9 +15,6 @@ import usb.core, usb.util
 
 DEBUG = 0
 
-# I2C-address of the SI570;  Thanks to Joachim Schneider, DB6QS
-si570_i2c_address = 0x55
-
 # Thanks to Ethan Blanton, KB8OJH, for this patch for the Si570 (many SoftRocks):
 # These are used by SetFreqByDirect(); see below.
 # The Si570 DCO must be clamped between these values
@@ -39,43 +36,44 @@ class Hardware(BaseHardware):
     BaseHardware.__init__(self, app, conf)
     self.usb_dev = None
     self.vfo = None
+    self.ptt_button = 0
+    self.is_cw = False
     self.key_thread = None
-    self.name_of_mic_play = conf.name_of_mic_play	# True if we can transmit
+    self.si570_i2c_address = conf.si570_i2c_address
   def open(self):			# Called once to open the Hardware
     # find our device
-    self.usb_dev = usb.core.find(idVendor=self.conf.usb_vendor_id, idProduct=self.conf.usb_product_id)
-    if self.usb_dev is None:
+    usb_dev = usb.core.find(idVendor=self.conf.usb_vendor_id, idProduct=self.conf.usb_product_id)
+    if usb_dev is None:
       text = 'USB device not found VendorID 0x%X ProductID 0x%X' % (
           self.conf.usb_vendor_id, self.conf.usb_product_id)
       self.application.sound_error = 1
     else:
       try:		# This exception occurs for the Peabody SDR.  Thanks to ON7VQ for figuring out the problem,
-        self.usb_dev.set_configuration()        # and to David, AE9RB, for the fix.
+        usb_dev.set_configuration()        # and to David, AE9RB, for the fix.
       except:
         if DEBUG: traceback.print_exc()
       try:
-        ret = self.usb_dev.ctrl_transfer(IN, 0x00, 0x0E00, 0, 2)
+        ret = usb_dev.ctrl_transfer(IN, 0x00, 0x0E00, 0, 2)
       except:
         if DEBUG: traceback.print_exc()
         text = "No permission to access the SoftRock USB interface"
         self.application.sound_error = 1
-        self.usb_dev = None
       else:
+        self.usb_dev = usb_dev		# success
         if len(ret) == 2:
           ver = "%d.%d" % (ret[1], ret[0])
         else:
           ver = 'unknown'
         text = 'Capture from SoftRock USB on %s, Firmware %s' % (self.conf.name_of_sound_capt , ver)
-        if self.name_of_mic_play and self.conf.key_poll_msec:
-          self.key_thread = KeyThread(self.usb_dev, self.conf.key_poll_msec / 1000.0)
+        if self.conf.name_of_mic_play and self.conf.key_poll_msec:
+          self.key_thread = KeyThread(usb_dev, self.conf.key_poll_msec / 1000.0, self.conf.key_hang_time)
           self.key_thread.start()
-    if self.name_of_mic_play:
-      self.application.bottom_widgets.info_text.SetLabel(text)
+    self.application.bottom_widgets.info_text.SetLabel(text)
     if DEBUG:
       print ('Startup freq', self.GetStartupFreq())
       print ('Run freq', self.GetFreq())
-      print ('Address 0x%X' % self.usb_dev.ctrl_transfer(IN, 0x41, 0, 0, 1)[0])
-      sm = self.usb_dev.ctrl_transfer(IN, 0x3B, 0, 0, 2)
+      print ('Address 0x%X' % usb_dev.ctrl_transfer(IN, 0x41, 0, 0, 1)[0])
+      sm = usb_dev.ctrl_transfer(IN, 0x3B, 0, 0, 2)
       sm = UBYTE2.unpack(sm)[0]
       print ('Smooth tune', sm)
     return text
@@ -101,7 +99,14 @@ class Hardware(BaseHardware):
     return None, None		# frequencies have not changed
   def ChangeMode(self, mode):		# Change the tx/rx mode
     # mode is a string: "USB", "AM", etc.
-    pass
+    if mode in ('CWU', 'CWL'):
+      self.is_cw = True
+    else:
+      self.is_cw = False
+    if self.key_thread:
+      self.key_thread.IsCW(self.is_cw)
+    elif hasattr(self, 'OnButtonPTT'):
+      self.OnButtonPTT()
   def ChangeBand(self, band):
     # band is a string: "60", "40", "WWV", etc.
     pass
@@ -109,21 +114,28 @@ class Hardware(BaseHardware):
     pass
   def HeartBeat(self):	# Called at about 10 Hz by the main
     pass
-  def OnButtonPTT(self, event):
-    if event.GetEventObject().GetValue():
-      self.OnPTT(1)
-    else:
-      self.OnPTT(0)
-  def OnPTT(self, ptt):
+  def OnButtonPTT(self, event=None):
+    if event:
+      if event.GetEventObject().GetValue():
+        self.ptt_button = 1
+      else:
+        self.ptt_button = 0
     if self.key_thread:
-      self.key_thread.OnPTT(ptt)
+      self.key_thread.OnPTT(self.ptt_button)
     elif self.usb_dev:
-      QS.set_key_down(ptt)
-      try:
-        self.usb_dev.ctrl_transfer(IN, 0x50, ptt, 0, 3)
-      except usb.core.USBError:
+      if self.is_cw:
         QS.set_key_down(0)
+        QS.set_transmit_mode(self.ptt_button)
+      else:
+        QS.set_key_down(self.ptt_button)
+      try:
+        self.usb_dev.ctrl_transfer(IN, 0x50, self.ptt_button, 0, 3)
+      except usb.core.USBError:
         if DEBUG: traceback.print_exc()
+        try:
+          self.usb_dev.ctrl_transfer(IN, 0x50, self.ptt_button, 0, 3)
+        except usb.core.USBError:
+          if DEBUG: traceback.print_exc()
   def GetStartupFreq(self):	# return the startup frequency / 4
     if not self.usb_dev:
       return 0
@@ -142,9 +154,11 @@ class Hardware(BaseHardware):
     return freq
   def SetFreqByValue(self, freq):
     freq = int(freq/1.0e6 * 2097152.0 * 4.0 + 0.5)
+    if freq <= 0:
+      return
     s = UBYTE4.pack(freq)
     try:
-      self.usb_dev.ctrl_transfer(OUT, 0x32, si570_i2c_address + 0x700, 0, s)
+      self.usb_dev.ctrl_transfer(OUT, 0x32, self.si570_i2c_address + 0x700, 0, s)
     except usb.core.USBError:
       if DEBUG: traceback.print_exc()
     else:
@@ -193,41 +207,63 @@ class Hardware(BaseHardware):
     s = struct.Struct('>BBL').pack((hsdiv_new << 5) + (n1_new >> 2),
                                    ((n1_new & 0x3) << 6) + (rfreq_int >> 4),
                                    ((rfreq_int & 0xf) << 28) + rfreq_frac)
-    self.usb_dev.ctrl_transfer(OUT, 0x30, si570_i2c_address + 0x700, 0, s)
+    self.usb_dev.ctrl_transfer(OUT, 0x30, self.si570_i2c_address + 0x700, 0, s)
     return True		# Success
 
 class KeyThread(threading.Thread):
   """Create a thread to monitor the key state."""
-  def __init__(self, dev, poll_secs):
+  def __init__(self, dev, poll_secs, key_hang_time):
     self.usb_dev = dev
     self.poll_secs = poll_secs
-    self.ptt = 0
-    self.key_down = 0
+    self.key_hang_time = key_hang_time
+    self.ptt_button = 0
+    self.currently_in_tx = 0
+    self.is_cw = False
+    self.key_timer = 0
+    self.is_transmit = 0
     threading.Thread.__init__(self)
     self.doQuit = threading.Event()
     self.doQuit.clear()
   def run(self):
     while not self.doQuit.isSet():
-      try:
-        if self.ptt:
-          key_down = 1
-        else:		# read key state
+      if self.is_cw:
+        try:		# Test key up/down state
           ret = self.usb_dev.ctrl_transfer(IN, 0x51, 0, 0, 1)
-          # bit 0x20 is the tip, bit 0x02 is the ring
+        except usb.core.USBError:
+          if DEBUG: traceback.print_exc()
+        else:
+          # bit 0x20 is the tip, bit 0x02 is the ring (ring not used)
           if ret[0] & 0x20:		# Tip: key is up
-            key_down = 0
+            QS.set_key_down(0)
+            if self.is_transmit and time.time() - self.key_timer > self.key_hang_time:
+              self.is_transmit = 0
           else:			# key is down
-            key_down = 1
-        if key_down != self.key_down:
-          self.key_down = key_down
-          self.usb_dev.ctrl_transfer(IN, 0x50, key_down, 0, 3)
-          QS.set_key_down(key_down)
-      except usb.core.USBError:
-        QS.set_key_down(0)
-        if DEBUG: traceback.print_exc()
+            QS.set_key_down(1)
+            self.is_transmit = 1
+            self.key_timer = time.time()
+          if self.is_transmit != self.currently_in_tx:
+            try:
+              self.usb_dev.ctrl_transfer(IN, 0x50, self.is_transmit, 0, 3)
+            except usb.core.USBError:
+              if DEBUG: traceback.print_exc()
+            else:
+              self.currently_in_tx = self.is_transmit	# success
+              QS.set_transmit_mode(self.is_transmit)
+              if DEBUG: print ("Change currently_in_tx", self.currently_in_tx)
+      elif self.ptt_button != self.currently_in_tx:
+        QS.set_key_down(self.ptt_button)
+        try:
+          self.usb_dev.ctrl_transfer(IN, 0x50, self.ptt_button, 0, 3)
+        except usb.core.USBError:
+          if DEBUG: traceback.print_exc()
+        else:
+          self.currently_in_tx = self.ptt_button	# success
+          if DEBUG: print ("Change currently_in_tx", self.currently_in_tx)
       time.sleep(self.poll_secs)
   def stop(self):
     """Set a flag to indicate that the thread should end."""
     self.doQuit.set()
   def OnPTT(self, ptt):
-    self.ptt = ptt
+    self.ptt_button = ptt
+  def IsCW(self, is_cw):
+    self.is_cw = is_cw
