@@ -22,17 +22,21 @@
 // "handle" is either an alsa handle or a portaudio stream if the stream is open;
 // otherwise it is NULL for a closed device.
 
-// This sends the microphone samples to the FFT instead of the radio samples.
-#define DEBUG_MIC	0
+// Set DEBUG_MIC (in quisk.h) to send the microphone samples to the FFT instead of the radio samples.
+// The sample rate and mic sample rate must be 48000.  Use -c n2adr/conf4.py.
+// 0: Normal operation.
+// 1: Send filtered mic output to the FFT.
+// 2: Send mic playback to the FFT.
+// 3: Send unfiltered mic output to the FFT.
 
 #if DEBUG_IO
 static int debug_timer = 1;		// count up number of samples
 #endif
 
-static struct sound_dev Capture, Playback, MicCapture, MicPlayback, DigitalInput, DigitalOutput;
+static struct sound_dev Capture, Playback, MicCapture, MicPlayback, DigitalInput, DigitalOutput, RawSamplePlayback;
 // These are arrays of all capture and playback devices, and MUST end with NULL:
 static struct sound_dev * CaptureDevices[] = {&Capture, &MicCapture, &DigitalInput, NULL};
-static struct sound_dev * PlaybackDevices[] = {&Playback, &MicPlayback, &DigitalOutput, NULL};
+static struct sound_dev * PlaybackDevices[] = {&Playback, &MicPlayback, &DigitalOutput, &RawSamplePlayback, NULL};
 
 struct sound_conf quisk_sound_state;	// Current sound status
 
@@ -283,6 +287,9 @@ int quisk_read_sound(void)	// Called from sound thread
 	static double cwCount=0;
 	static complex tuneVector = (double)CLIP32 / CLIP16;	// Convert 16-bit to 32-bit samples
 	static struct quisk_cFilter filtInterp={NULL};
+#if DEBUG_MIC == 1
+	complex tmpSamples[SAMP_BUFFER_SIZE];
+#endif
 
 	quisk_sound_state.interupts++;
 #if DEBUG_IO > 1
@@ -334,6 +341,13 @@ int quisk_read_sound(void)	// Called from sound thread
 		record_samples(NULL, -2);		 // Close file
 		is_recording_samples = 0;
 	}
+	// Perhaps write samples to a loopback device for use by another program
+	if (RawSamplePlayback.handle) {
+		if (RawSamplePlayback.portaudio_index < 0)
+			quisk_play_alsa(&RawSamplePlayback, nSamples, cSamples, 0, 1.0);
+		else
+			quisk_play_portaudio(&RawSamplePlayback, nSamples, cSamples, 0, 1.0);
+	}
 #if ! DEBUG_MIC
 	nSamples = quisk_process_samples(cSamples, nSamples);
 #endif
@@ -395,16 +409,16 @@ int quisk_read_sound(void)	// Called from sound thread
 	if (mic_count > 0) {
 #if DEBUG_IO > 1
 		QuiskPrintTime("  mic-read", 0);
+#endif
+#if DEBUG_MIC == 3
+		quisk_process_samples(cSamples, mic_count);
 #endif
 		// quisk_process_microphone returns samples at the sample rate MIC_OUT_RATE
 		mic_count = quisk_process_microphone(mic_sample_rate, cSamples, mic_count);
 #if DEBUG_MIC == 1
-		if ( ! quisk_is_key_down())
-			for (i = 0; i < mic_count; i++)
-				cSamples[i] = 0;
 		for (i = 0; i < mic_count; i++)
-			cSamples[i] *= (double)CLIP32 / CLIP16;	// convert 16-bit samples to 32 bits
-		quisk_process_samples(cSamples, mic_count);
+			tmpSamples[i] = cSamples[i] * (double)CLIP32 / CLIP16;	// convert 16-bit samples to 32 bits
+		quisk_process_samples(tmpSamples, mic_count);
 #endif
 #if DEBUG_IO > 1
 		QuiskPrintTime("  mic-proc", 0);
@@ -449,11 +463,9 @@ int quisk_read_sound(void)	// Called from sound thread
 				}
 			}
 		}
-		else {		// Transmit SSB
-			if ( ! quisk_is_key_down()) {
-				for (i = 0; i < mic_count; i++)
-					cSamples[i] = 0.0;
-			}
+		else if( ! DEBUG_MIC && ! quisk_is_key_down()) {		// Transmit SSB
+			for (i = 0; i < mic_count; i++)
+				cSamples[i] = 0.0;
 		}
 		// Perhaps interpolate the mic samples back to the mic play rate
 		mic_interp = MicPlayback.sample_rate / MIC_OUT_RATE;
@@ -552,6 +564,11 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalOutput.sample_rate = quisk_sound_state.playback_rate;	// Radio sound play rate
 	DigitalOutput.channel_I = 0;
 	DigitalOutput.channel_Q = 1;
+	// Playback device for raw samples
+	strncpy(RawSamplePlayback.name, QuiskGetConfigString ("sample_playback_name", ""), QUISK_SC_SIZE);
+	RawSamplePlayback.sample_rate = quisk_sound_state.sample_rate;
+	RawSamplePlayback.channel_I = 0;
+	RawSamplePlayback.channel_Q = 1;
 
 	set_num_channels (&Capture);
 	set_num_channels (&Playback);
@@ -559,6 +576,7 @@ void quisk_open_sound(void)	// Called from GUI thread
 	set_num_channels (&MicPlayback);
 	set_num_channels (&DigitalInput);
 	set_num_channels (&DigitalOutput);
+	set_num_channels (&RawSamplePlayback);
 
 #ifdef FIX_H101
 	Capture.channel_Delay = Capture.channel_Q;	// Obsolete; do not use.
@@ -595,6 +613,9 @@ void quisk_open_sound(void)	// Called from GUI thread
 	DigitalInput.latency_frames = 0;
 	DigitalOutput.read_frames = 0;
 	DigitalOutput.latency_frames = DigitalOutput.sample_rate * 500 / 1000;	// 500 milliseconds
+	// set capture and playback for raw samples
+	RawSamplePlayback.read_frames = 0;
+	RawSamplePlayback.latency_frames = RawSamplePlayback.sample_rate * 500 / 1000;	// 500 milliseconds
 #if DEBUG_IO
 	printf("Sample buffer size %d, latency msec %d\n", SAMP_BUFFER_SIZE, quisk_sound_state.latency_millisecs);
 #endif
@@ -695,6 +716,7 @@ PyObject * quisk_sound_errors(PyObject * self, PyObject * args)
 	AddCard(&Playback,	pylist, "Play radio sound");
 	AddCard(&MicPlayback,	pylist, "Play microphone sound");
 	AddCard(&DigitalOutput,	pylist, "Play digital mode sound");
+	AddCard(&RawSamplePlayback, pylist, "Play raw samples");
 	return pylist;
 }
 
