@@ -860,9 +860,9 @@ void quisk_close_sound_alsa(struct sound_dev ** pCapture, struct sound_dev ** pP
 	}
 }
 
-void quisk_mixer_set(char * card_name, int numid, double value, char * err_msg, int err_size)
-// Set card card_name mixer control numid to 0.0 <= value <= 1.0, for integer
-// or boolean (0 or 1) controls.
+void quisk_mixer_set(char * card_name, int numid, PyObject * value, char * err_msg, int err_size)
+// Set card card_name mixer control numid to value for integer, boolean, enum controls.
+// If value is a float, interpret value as a decimal fraction of min/max.
 {
 	int err;
 	static snd_ctl_t * handle = NULL;
@@ -878,10 +878,6 @@ void quisk_mixer_set(char * card_name, int numid, double value, char * err_msg,
 	snd_ctl_elem_value_alloca(&control);
 
 	err_msg[0] = 0;
-	if (value < 0)
-		value = 0;
-	else if (value > 1.0)
-		value = 1.0;
 
 	snd_ctl_elem_id_set_interface(id, SND_CTL_ELEM_IFACE_MIXER);
 	snd_ctl_elem_id_set_numid(id, numid);
@@ -915,7 +911,7 @@ void quisk_mixer_set(char * card_name, int numid, double value, char * err_msg,
 	idx = 0;
 	switch (type) {
 	case SND_CTL_ELEM_TYPE_BOOLEAN:
-		if (value > 0.5)
+		if (PyObject_IsTrue(value))
 			snd_ctl_elem_value_set_boolean(control, idx, 1);
 		else
 			snd_ctl_elem_value_set_boolean(control, idx, 0);
@@ -923,14 +919,41 @@ void quisk_mixer_set(char * card_name, int numid, double value, char * err_msg,
 	case SND_CTL_ELEM_TYPE_INTEGER:
 		imin = snd_ctl_elem_info_get_min(info);
 		imax = snd_ctl_elem_info_get_max(info);
-		tmp = (long)(imin + (imax - imin) * value + 0.4);
-		snd_ctl_elem_value_set_integer(control, idx, tmp);
+		if (PyFloat_CheckExact(value)) {
+			tmp = (long)(imin + (imax - imin) * PyFloat_AsDouble(value) + 0.4);
+			snd_ctl_elem_value_set_integer(control, idx, tmp);
+		}
+		else if(PyInt_Check(value)) {
+			tmp = PyInt_AsLong(value);
+			snd_ctl_elem_value_set_integer(control, idx, tmp);
+		}
+		else {
+			snprintf (err_msg, err_size, "Control %s id %d has bad value\n", card_name, numid);
+		}
 		break;
 	case SND_CTL_ELEM_TYPE_INTEGER64:
 		imin = snd_ctl_elem_info_get_min64(info);
 		imax = snd_ctl_elem_info_get_max64(info);
-		tmp = (long)(imin + (imax - imin) * value + 0.4);
-		snd_ctl_elem_value_set_integer64(control, idx, tmp);
+		if (PyFloat_CheckExact(value)) {
+			tmp = (long)(imin + (imax - imin) * PyFloat_AsDouble(value) + 0.4);
+			snd_ctl_elem_value_set_integer64(control, idx, tmp);
+		}
+		else if(PyInt_Check(value)) {
+			tmp = PyInt_AsLong(value);
+			snd_ctl_elem_value_set_integer64(control, idx, tmp);
+		}
+		else {
+			snprintf (err_msg, err_size, "Control %s id %d has bad value\n", card_name, numid);
+		}
+		break;
+	case SND_CTL_ELEM_TYPE_ENUMERATED:
+		if(PyInt_Check(value)) {
+			tmp = PyInt_AsLong(value);
+			snd_ctl_elem_value_set_enumerated(control, idx, (unsigned int)tmp);
+		}
+		else {
+			snprintf (err_msg, err_size, "Control %s id %d has bad value\n", card_name, numid);
+		}
 		break;
 	default:
 		snprintf (err_msg, err_size, "Control %s element has unknown type\n", card_name);
