@@ -602,7 +602,7 @@ int  quisk_read_portaudio(struct sound_dev * dev, complex * samp)
 	return 0;
 }
 
-void quisk_mixer_set(char * card_name, int numid, double value, char * err_msg, int err_size)
+void quisk_mixer_set(char * card_name, int numid, PyObject * value, char * err_msg, int err_size)
 {
 	err_msg[0] = 0;
 }
